/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** ActGroup.c
**
** Creation date: 16.12.2007
** Last modified: 22.12.2007
*/

#include "system.h"
#include "ActGroup_mcc.h"
#include <proto/utility.h>

#define SUPERCLASS MUIC_Group

static struct MUI_CustomClass *ActGroup_mcc = NULL;    /* for MUI */
struct IClass *ActGroupClass = NULL;                   /* for Intuition */

struct Data
{
    struct MUI_EventHandlerNode ehnode;
};

static IPTR mNew(struct IClass *cl, Object *obj, struct opSet *msg)
{
    struct Data *data;

    obj = (Object *)DoSuperMethodA(cl, obj, (Msg)msg);
    if (obj == NULL) {
	return 0;
    }

    data = INST_DATA(cl, obj);
    memset(data, 0, sizeof(struct Data));

    return (IPTR)obj;
}

static IPTR mShow(struct IClass *cl, Object *obj, Msg msg)
{
    struct Data *data = INST_DATA(cl, obj);

    if (!DoSuperMethodA(cl, obj, msg)) {
	return FALSE;
    }

    data->ehnode.ehn_Object = obj;
    data->ehnode.ehn_Class  = cl;
    data->ehnode.ehn_Events = IDCMP_MOUSEBUTTONS;
    /* data->ehnode.ehn_Priority = -10;	   give priority to other object */
    DoMethod(_win(obj), MUIM_Window_AddEventHandler, &data->ehnode);

    return TRUE;
}

static IPTR mHide(struct IClass *cl, Object *obj, Msg msg)
{
    struct Data *data = INST_DATA(cl, obj);

    DoMethod(_win(obj), MUIM_Window_RemEventHandler, &data->ehnode);
    return DoSuperMethodA(cl, obj, msg);
}

#if 0
static bool isa(struct IClass *class1, struct IClass *class2)
{
    while (class1) {
	if (class1 == class2) {
	    return TRUE;
	}
	class1 = class1->cl_Super;
    }
    return FALSE;
}
#endif

#define _between(a,x,b) ((x)>=(a) && (x)<=(b))
#define _isinobject(x,y) (_between(_mleft(obj),(x),_mright (obj)) \
	&& _between(_mtop(obj) ,(y),_mbottom(obj)))

static IPTR mHandleEvent(struct IClass *cl, Object *obj, 
	struct  MUIP_HandleEvent *msg)
{
    struct IntuiMessage *imsg = msg->imsg;

    if (imsg && imsg->Class == IDCMP_MOUSEBUTTONS && imsg->Code == SELECTDOWN &&
	    _isinobject(imsg->MouseX, imsg->MouseY)) {
	/* 
	** As of NList_mcc V0.101 the behavior in NList 
	** has been changed and we can activate as usual.
	*/
	set(_win(obj), MUIA_Window_ActiveObject, obj);
    }
    return 0;
}

DISPATCHER_PROTO
{
    switch (msg->MethodID) {
	case OM_NEW:		return mNew(cl, obj, (APTR)msg);
	case MUIM_Show: 	return mShow(cl, obj, (APTR)msg);
	case MUIM_Hide: 	return mHide(cl, obj, (APTR)msg);
        case MUIM_HandleEvent:	return mHandleEvent(cl, obj, (APTR)msg);
    }
    return DoSuperMethodA(cl, obj, msg);
}

void ActGroupCleanup(void)
{
    if (ActGroup_mcc != NULL) {
        MUI_DeleteCustomClass(ActGroup_mcc);
    }
    ActGroup_mcc = NULL;
    ActGroupClass = NULL;
}

BOOL ActGroupInit(void)
{
    ActGroup_mcc = MUI_CreateCustomClass(NULL, (STRPTR)SUPERCLASS, NULL,
        sizeof(struct Data), Dispatcher);
    if (ActGroup_mcc == NULL) {
        return FALSE;
    }
    ActGroupClass = ActGroup_mcc->mcc_Class;
    DISPATCHER_INIT(ActGroupClass);

    return TRUE;
}

