/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** DDList_mcc.h
**
** Creation date: 05.05.1996
** Last modified: 28.04.2008
**
** DDList.mcc is a subclass of List class.
** It adds some new Hook functions and the availability to
** "hear" Drop actions.
*/

#ifndef MUI_DDLIST_MCC_H
#define MUI_DDLIST_MCC_H

#include <intuition/classes.h>

/*
** Attributes and methods for the new class.
** Your tags have to be named MUI(A/M)_<classname>_<foobar>.
** The upper sixteen bits of your tag values need to be
** (TAG_USER | ( <your MUI serial Nr> << 16 ))
** Again, classes with invalid tag specs are promised to
** go on the blacklist. This implies that you have to
** be a registered MUI user if you want to distribute
** public classes.
*/

extern struct IClass *DDListClass;

#define TAG_DDLIST_BASE (TAG_USER | (140 << 16) | 0x20)

/*
** Funcs are of type IPTR (*)(Object *ddlist_object, struct MUIP_DragDrop *msg, void *dragData)
**
** You will only be called when msg->obj != ddlist_object
** (in this case the parent class will be asked).
*/

#define MUIA_DDList_DragQuery   (TAG_DDLIST_BASE | 0x0)              /* [IS.] */
#define MUIA_DDList_DragDrop    (TAG_DDLIST_BASE | 0x1)              /* [IS.] */

#define MUIA_DDList_DragData    (TAG_DDLIST_BASE | 0x2)              /* [IS.] */

#define MUIA_DDList_Dropped     (TAG_DDLIST_BASE | 0x3)              /* [..G] */

#define MUIA_DDList_MemPool     (TAG_DDLIST_BASE | 0x4)              /* [..G] */

#define DDListObject BOOPSIOBJMACRO_START(DDListClass)

BOOL DDListInit(void);
void DDListCleanup(void);

#endif
