/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** DataTypes_mcc.h
**
** Creation date: 13.02.1997
** Last modified: 11.07.2020
**
** DataTypes.mcc is a subclass of Area class.
** It displays an external datatypes object.
*/

#ifndef MUI_DATATYPES_MCC_H
#define MUI_DATATYPES_MCC_H

#include <intuition/classusr.h>

/*
** Function for loading a datatypes picture from a filename,
** free with DisposeDTObject
*/
Object *LoadDTPicture(const char *filename);

/*
** Attributes and methods for the new class.
** Your tags have to be named MUI(A/M)_<classname>_<foobar>.
** The upper sixteen bits of your tag values need to be
** (TAG_USER | ( <your MUI serial Nr> << 16 ))
** Again, classes with invalid tag specs are promised to
** go on the blacklist. This implies that you have to
** be a registered MUI user if you want to distribute
** public classes.
*/

extern struct IClass *DataTypesClass;

#define TAG_DATATYPES_BASE (TAG_USER | (140 << 16) | 0x10)

/* loading a dtpicture from filename */
#define MUIA_DataTypes_Filename  (TAG_DATATYPES_BASE | 0x0)         /* [IS.] */
/* using an existing dtpicture owned by the caller */
#define MUIA_DataTypes_Object    (TAG_DATATYPES_BASE | 0x1)         /* [IS.] */
#define MUIA_DataTypes_FixedSize (TAG_DATATYPES_BASE | 0x2)         /* [ISG] */
#define MUIA_DataTypes_Scale     (TAG_DATATYPES_BASE | 0x3)         /* [IS.] */
#define MUIA_DataTypes_KeepAspect (TAG_DATATYPES_BASE | 0x4)        /* [IS.] */
/* for saving the base font */
#define MUIA_DataTypes_SaveBaseFont  (TAG_DATATYPES_BASE | 0x5)     /* [IS.] */

#define DataTypesObject BOOPSIOBJMACRO_START(DataTypesClass)

BOOL DataTypesInit(void);
void DataTypesCleanup(void);

#endif

