/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** ExtApplication_mcc.h
**
** Creation date: 12.01.1997
** Last modified: 27.04.2008
**
** ExtApplication.mcc is a subclass of Application class.
** It offers a new method for save and postponed deletion of MUI objects.
*/

#ifndef MUI_EXTAPPLICATION_MCC_H
#define MUI_EXTAPPLICATION_MCC_H

/*
** Attributes and methods for the new class.
** Your tags have to be named MUI(A/M)_<classname>_<foobar>.
** The upper sixteen bits of your tag values need to be
** (TAG_USER | ( <your MUI serial Nr> << 16 ))
** Again, classes with invalid tag specs are promised to
** go on the blacklist. This implies that you have to
** be a registered MUI user if you want to distribute
** public classes.
*/

extern struct IClass *ExtApplicationClass;

#define TAG_EXTAPPLICATION_BASE (TAG_USER | (140 << 16) | 0x40)

#define MUIA_ExtApplication_ActiveExtWindow (TAG_EXTAPPLICATION_BASE | 0x0)        /* [ISG] */

#define MUIM_ExtApplication_DisposeObject (TAG_EXTAPPLICATION_BASE | 0x8)

struct MUIP_ExtApplication_DisposeObject
{
    ULONG MethodID;
    Object *eado_Object;
};

#define MUIM_ExtApplication_ProjectSleep (TAG_EXTAPPLICATION_BASE | 0x9)

struct MUIP_ExtApplication_ProjectSleep
{
    ULONG MethodID;
    struct Project *eaps_Project;
    ULONG eaps_Sleep;
};

/*
** Redirects reply address to internal message port
*/
#define MUIM_ExtApplication_RedirectMessage (TAG_EXTAPPLICATION_BASE | 0xA)

struct MUIP_ExtApplication_RedirectMessage
{
    ULONG MethodID;
    struct Message *earm_Message;
};

/*
** Removes message from internal message port.  Returns pointer
** to msg of NULL if message not present.
*/
#define MUIM_ExtApplication_GetMessage (TAG_EXTAPPLICATION_BASE | 0xB)

struct MUIP_ExtApplication_GetMessage
{
    ULONG MethodID;
    struct Message *eagm_Message;
};

#define ExtApplicationObject BOOPSIOBJMACRO_START(ExtApplicationClass)

BOOL ExtApplicationInit(void);
void ExtApplicationCleanup(void);

#endif
