/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** ExtEditor_mcc.h
**
** Creation date: 27.02.1996
** Last modified: 06.03.2011
**
** ExtEditor.mcc is a subclass of TextEditor class.
** It attaches a context menu strip to the editor object.
** On MorphOS we directly use the Textinput class.
*/

#ifndef MUI_EXTEDITOR_MCC_H
#define MUI_EXTEDITOR_MCC_H

#include <system.h>

#ifdef USE_TEXTEDITOR

#include <mui/TextEditor_mcc.h>

#define MUIA_ExtEditor_Quiet MUIA_TextEditor_Quiet
#define MUIA_ExtEditor_Top MUIA_TextEditor_Prop_First
#define MUIA_ExtEditor_Contents MUIA_TextEditor_Contents
#define MUIA_ExtEditor_HasChanged MUIA_TextEditor_HasChanged

/*
** Attributes and methods for the new class.
** Your tags have to be named MUI(A/M)_<classname>_<foobar>.
** The upper sixteen bits of your tag values need to be
** (TAG_USER | ( <your MUI serial Nr> << 16 ))
** Again, classes with invalid tag specs are promised to
** go on the blacklist. This implies that you have to
** be a registered MUI user if you want to distribute
** public classes.
*/

#define TAG_EXTEDITOR_BASE (TAG_USER | (140 << 16) | 0x50)

/*
** Funcs are of type void (*)(Object *exteditor_object, void *funcData)
*/
#define MUIA_ExtEditor_LoadFunc    (TAG_EXTEDITOR_BASE | 0x0)        /* [I..] */
#define MUIA_ExtEditor_SaveFunc    (TAG_EXTEDITOR_BASE | 0x1)        /* [I..] */
#define MUIA_ExtEditor_ExternalEditorFunc (TAG_EXTEDITOR_BASE | 0x2) /* [I..] */

#define MUIA_ExtEditor_FuncData    (TAG_EXTEDITOR_BASE | 0x3)        /* [I..] */

#elif defined(USE_TEXTINPUT)

#define MUIA_ExtEditor_Quiet MUIA_Textinput_Quiet
#define MUIA_ExtEditor_Top MUIA_Textinput_TopLine
#define MUIA_ExtEditor_Contents MUIA_Textinput_Contents
#define MUIA_ExtEditor_HasChanged MUIA_Textinput_Changed

#else

#error "No text editor class defined!"

#endif

extern struct IClass *ExtEditorClass;

#define ExtEditorObject BOOPSIOBJMACRO_START(ExtEditorClass)

bool ExtEditorInit(void);
void ExtEditorCleanup(void);

char *ExtEditorGetContents(Object *obj, struct MemPool *memPool);
/*
** Returns editor buffer allocated from given mempool.
*/

void ExtEditorSetCursor(Object *obj, long line, long col);
/*
** Sets cursor pos. Line and col start with 1.
*/

void ExtEditorGetCursor(Object *obj, long *line, long *col);
/*
** Gets cursor pos. Line and col start with 1 and may be NULL.
*/

#endif
