/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** ExtWindow_mcc.h
**
** Creation date: 16.03.1997
** Last modified: 14.09.2015
**
** ExtWindow.mcc is a subclass of Window class.
** It offers:
**      new attribute for project handling
**      prepending the window title
**      setting the MenuPickWindow of its application
**      event handlers for key presses and mouse clicks.
**	Qualifier of last IntuiMessage.
*/

#ifndef MUI_EXTWINDOW_MCC_H
#define MUI_EXTWINDOW_MCC_H

/*
** Attributes and methods for the new class.
** Your tags have to be named MUI(A/M)_<classname>_<foobar>.
** The upper sixteen bits of your tag values need to be
** (TAG_USER | ( <your MUI serial Nr> << 16 ))
** Again, classes with invalid tag specs are promised to
** go on the blacklist. This implies that you have to
** be a registered MUI user if you want to distribute
** public classes.
*/

extern struct IClass *ExtWindowClass;

#define TAG_EXTWINDOW_BASE (TAG_USER | (140 << 16) | 0x60)

#define MUIA_ExtWindow_Project  (TAG_EXTWINDOW_BASE | 0x0)      /* [ISG] */

#define MUIA_ExtWindow_PrependTitle (TAG_EXTWINDOW_BASE | 0x1)   /* [ISG] */

#define MUIA_ExtWindow_IconifyFunc (TAG_EXTWINDOW_BASE | 0x2)   /* [ISG] */

#define MUIA_Qualifier (TAG_EXTWINDOW_BASE | 0x3)   /* [ISG] */

#define ExtWindowObject BOOPSIOBJMACRO_START(ExtWindowClass)

BOOL ExtWindowInit(void);
void ExtWindowCleanup(void);

#endif
