/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** SFWList_mcc.h
**
** Creation date: 30.10.1996
** Last modified: 10.05.2022
**
** SFWList.mcc is a subclass of List (or NList if USE_NLIST is defined) class.
** Its purpose is for displaying the contents of a program element 
** (usually the result of a Select-From-Where query).
** It also attaches a context menu to enable further operations.
*/

#ifndef MUI_SFWLIST_MCC_H
#define MUI_SFWLIST_MCC_H

#include <system.h>
#include <intuition/classes.h>

/*
** Attributes and methods for the new class.
** Your tags have to be named MUI(A/M)_<classname>_<foobar>.
** The upper sixteen bits of your tag values need to be
** (TAG_USER | ( <your MUI serial Nr> << 16 ))
** Again, classes with invalid tag specs are promised to
** go on the blacklist. This implies that you have to
** be a registered MUI user if you want to distribute
** public classes.
*/

extern struct IClass *SFWListClass;

#define TAG_SFWLIST_BASE (TAG_USER | (140 << 16) | 0x90)

#define MUIA_SFWList_NumFields  (TAG_SFWLIST_BASE | 0x1)     /* (ushort)   (..G) */
#define MUIA_SFWList_FieldInfos (TAG_SFWLIST_BASE | 0x2)     /* (QueryFieldInfo *)   (..G) */
#define MUIA_SFWList_Titles     (TAG_SFWLIST_BASE | 0x3)     /* (struct QueryLine *) (..G) */

#define MUIA_SFWList_ShowTitles (TAG_SFWLIST_BASE | 0x4)     /* (bool)     (I..) */
#define MUIA_SFWList_SeparatorBars (TAG_SFWLIST_BASE | 0x5)  /* (bool)     (I..) */
#define MUIA_SFWList_CheckMarks (TAG_SFWLIST_BASE | 0x6)     /* (bool)     (I..) */
#define MUIA_SFWList_NumSelected (TAG_SFWLIST_BASE | 0x7)    /* (long)     (..G) */
#define MUIA_SFWList_ActiveRecord (TAG_SFWLIST_BASE | 0x8)   /* (struct Record *)   (.SG) */
#define MUIA_SFWList_ActiveLine  (TAG_SFWLIST_BASE | 0x9)    /* (long)     (.SG) */
#define MUIA_SFWList_ColumnOrder (TAG_SFWLIST_BASE | 0xA)    /* (char *)   (..G) */
#define MUIA_SFWList_ControlTable (TAG_SFWLIST_BASE | 0xB)   /* (struct Table *)   (..G) */
#define MUIA_SFWList_MoveDrop (TAG_SFWLIST_BASE | 0xC)       /* LONG (..GN) */

#define MUIM_SFWList_GetRecord  (TAG_SFWLIST_BASE | 0x10)
#define MUIM_SFWList_SetTitlesBody  (TAG_SFWLIST_BASE | 0x11)
#define MUIM_SFWList_SetElement (TAG_SFWLIST_BASE | 0x12)
#define MUIM_SFWList_SetString  (TAG_SFWLIST_BASE | 0x13)
#define MUIM_SFWList_SetSelected (TAG_SFWLIST_BASE | 0x14)
#define MUIM_SFWList_GetSelected (TAG_SFWLIST_BASE | 0x15)
#define MUIM_SFWList_RemRecord  (TAG_SFWLIST_BASE | 0x16)
#define MUIM_SFWList_RemAllRecords  (TAG_SFWLIST_BASE | 0x17)

struct MUIP_SFWList_GetRecord
{
    ULONG MethodID;
    long sfwl_Row;
};

struct MUIP_SFWList_SetTitlesBody
{
    ULONG MethodID;
    const struct Element *sfwl_Titles;
    const struct Element *sfwl_Body;
};

struct MUIP_SFWList_SetElement
{
    ULONG MethodID;
    const struct Element *sfwl_Element;
};

struct MUIP_SFWList_SetString
{
    ULONG MethodID;
    const char *sfwl_String;
};

struct MUIP_SFWList_SetSelected
{
    ULONG MethodID;
    const bool *sfwl_Selected;
};

struct MUIP_SFWList_GetSelected
{
    ULONG MethodID;
    bool *sfwl_Selected;
};

struct MUIP_SFWList_RemRecord
{
    ULONG MethodID;
    const struct Record *sfwl_Record;
};

#define SFWListObject BOOPSIOBJMACRO_START(SFWListClass)

BOOL SFWListInit(void);
void SFWListCleanup(void);

#endif

