/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** StringText.c
**
** Creation date: 04.05.1996
** Last modified: 08.12.2007
**
*/

/* Includes */
#include "system.h"
#include <intuition/icclass.h>
#include <clib/alib_protos.h>
#include <proto/utility.h>

#include "StringText_mcc.h"

#define SUPERCLASS MUIC_Text

static struct MUI_CustomClass *StringText_mcc = NULL;    /* for MUI */
struct IClass *StringTextClass = NULL;                   /* for Intuition */

struct Data
{
    char dummy[0];
};

static void makeOpSet(const struct opSet *in, 
	struct opSet *out, struct TagItem *extra)
{
    struct TagItem *tags = in->ops_AttrList;
    const struct TagItem *tag = FindTagItem(MUIA_String_Contents, tags);

    *out = *in;
    if (tag) {
	out->ops_AttrList = extra;
	extra[0].ti_Tag = MUIA_Text_Contents;
	extra[0].ti_Data = tag->ti_Data;
	extra[1].ti_Tag = TAG_MORE;
	extra[1].ti_Data = (IPTR)tags;
    }
}

static IPTR mNew(struct IClass *cl, Object *obj, struct opSet *msg)
{
    struct opSet copy;
    struct TagItem extra[2];
    struct Data *data;

    makeOpSet(msg, &copy, extra);
    obj = (Object *)DoSuperMethodA(cl, obj, (Msg)&copy);
    if (obj == NULL) {
	return 0;
    }

    data = INST_DATA(cl, obj);
    memset(data, 0, sizeof(struct Data));

    return (IPTR)obj;
}

static IPTR mSet(struct IClass *cl, Object *obj, struct opSet *msg)
{
    struct opSet copy;
    struct TagItem extra[2];

    makeOpSet(msg, &copy, extra);
    return DoSuperMethodA(cl, obj, (Msg)&copy);
}

static IPTR mGet(struct IClass *cl, Object *obj, struct opGet *msg)
{
    switch (msg->opg_AttrID)
    {
        case MUIA_String_Contents:
            *msg->opg_Storage = nget(obj, MUIA_Text_Contents);
            return TRUE;
    }
    return DoSuperMethodA(cl, obj, (Msg)msg);
}

DISPATCHER_PROTO
{
    switch (msg->MethodID)
    {
	case OM_NEW:		return mNew(cl, obj, (APTR)msg);
	case OM_SET:            return mSet(cl, obj, (APTR)msg);
	case OM_GET:            return mGet(cl, obj, (APTR)msg);
    }

    return DoSuperMethodA(cl, obj, msg);
}

void StringTextCleanup(void)
{
    if (StringText_mcc != NULL) {
        MUI_DeleteCustomClass(StringText_mcc);
    }
    StringText_mcc = NULL;
    StringTextClass = NULL;
}

BOOL StringTextInit(void)
{
    StringText_mcc = MUI_CreateCustomClass(NULL, (STRPTR)SUPERCLASS, NULL,
        sizeof(struct Data), Dispatcher);
    if (StringText_mcc == NULL) {
        StringTextCleanup();
        return FALSE;
    }

    StringTextClass = StringText_mcc->mcc_Class;
    DISPATCHER_INIT(StringTextClass);

    return TRUE;
}

