/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** WindowButton_mcc.c
**
** Creation date: 14.05.1997
** Last modified: 19.05.2020
**
*/

/* Includes */
#include <libraries/iffparse.h>         /* defines MAKE_ID */
#include "system.h"
#include "DataTypes_mcc.h"
#include "WindowButton_mcc.h"
#include <intuition/icclass.h>
#include <clib/alib_protos.h>
#include <proto/datatypes.h>
#include <proto/utility.h>

#undef USE_WINDOW_BUTTON_ICON

#define SUPERCLASS MUIC_Group

static struct MUI_CustomClass *WindowButton_mcc = NULL;    /* for MUI */
struct IClass *WindowButtonClass = NULL;                   /* for Intuition */

#ifdef USE_WINDOW_BUTTON_ICON
static Object *dtpicOpen = NULL;
static bool imagesLoaded = FALSE;

static void loadImages(void)
{
    if (!imagesLoaded) {
        dtpicOpen = LoadDTPicture("BeeBase:Images/open.png");
        imagesLoaded = TRUE;
    }
}

static void freeImages(void)
{
    if (dtpicOpen) {
        DisposeDTObject(dtpicOpen);
        dtpicOpen = NULL;
    }
    imagesLoaded = FALSE;
}
#endif

#if defined(__MORPHOS__)
static void HOOK_PROTO(onTextDisabled, GuiObject go, IPTR dummy)
{
    set(go, MUIA_Disabled, FALSE);
}
#endif

static IPTR mNew(struct IClass *cl, Object *obj, struct opSet *msg)
{
    struct TagItem *tags = msg->ops_AttrList;
    Object *text, *dots = NULL;

    obj = (Object *)DoSuperNew(cl, obj,
        MUIA_InputMode, MUIV_InputMode_RelVerify,
        MUIA_Group_HorizSpacing, 0,
        MUIA_Group_Horiz, TRUE,
        TAG_DONE);
    if (obj == NULL) {
        return 0;
    }

#ifdef USE_WINDOW_BUTTON_ICON
    loadImages();
    if (dtpicOpen != NULL) {
        Object *img = DataTypesObject,
            MUIA_DataTypes_Object, dtpicOpen,
            MUIA_DataTypes_FixedSize, TRUE,
            MUIA_DataTypes_Scale, FALSE,
            End;

        if (img) {
            MUIAddMember(obj, HSpace(2));
            MUIAddMember(obj, img);
            MUIAddMember(obj, HSpace(2));
        }
    }
#endif

    text =  TextObject,
        MUIA_Weight, 0,
        MUIA_Text_Contents, GetTagData(MUIA_Text_Contents, (IPTR)"", tags),
        MUIA_Text_PreParse, GetTagData(MUIA_Text_PreParse, (IPTR)"\33c", tags),
        End;
    if (text) {
        MUIAddMember(obj, HSpace(0));
        MUIAddMember(obj, text);
        dots =  TextObject, MUIA_Weight, 0, End;
        if (dots) {
            MUIAddMember(obj, dots);
#if defined(__MORPHOS__)
            MUIAddCallback(dots, MUIA_Disabled, TRUE, onTextDisabled, NULL);
#endif
        }
        MUIAddMember(obj, HSpace(0));
#if defined(__MORPHOS__)
        MUIAddCallback(text, MUIA_Disabled, TRUE, onTextDisabled, NULL);
#endif
    }

    set(obj, TAG_MORE, tags);
    if (dots) {
        set(dots, MUIA_Text_Contents, "...");
    }

    return (IPTR)obj;
}

DISPATCHER_PROTO
{
    switch (msg->MethodID) {
	case OM_NEW:		return(mNew(cl, obj, (APTR)msg));
    }

    return DoSuperMethodA(cl, obj, msg);
}

void WindowButtonCleanup(void)
{
    if (WindowButton_mcc != NULL) {
        MUI_DeleteCustomClass(WindowButton_mcc);
    }
    WindowButton_mcc = NULL;
    WindowButtonClass = NULL;
#ifdef USE_WINDOW_BUTTON_ICON
    freeImages();
#endif
}

BOOL WindowButtonInit(void)
{
    WindowButton_mcc = MUI_CreateCustomClass(NULL, (STRPTR)SUPERCLASS, NULL,
            0, Dispatcher);
    if (WindowButton_mcc == NULL) {
        WindowButtonCleanup();
        return FALSE;
    }

    WindowButtonClass = WindowButton_mcc->mcc_Class;
    DISPATCHER_INIT(WindowButtonClass);

    return TRUE;
}

