/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** preparse_mui.c
**
** Creation date: 21.06.2020
** Last modified: 06.07.2020
*/

#include "system.h"
#include "preparse_mui.h"
#include "util.h"
#include "memory.h"

static struct MemPool *PreParseMemPool = NULL;
static struct List PreParseList;

struct PreParseEntry
{
    struct Node ppe_Node;
    char ppe_PreParse[0];
};

void PreParseInit(void)
{
    NewList(&PreParseList);
    PreParseMemPool = CreatePool(0L, 4096, 1024);
}

void PreParseExit(void)
{
    if (PreParseMemPool != NULL) {
        DeletePool(PreParseMemPool);
	PreParseMemPool = NULL;
        NewList(&PreParseList);
    }
}

#define MAX_PREPARSE_SPEC \
   (2  +  2  +  2  +  2  +  2  +  2  +  2  +  2  +  1+8+1  +  2  +  1+8+1   + 1)
// ESC b ESC i ESC u ESC s ESC o ESC g ESC n ESP P[XXRRGGBB] ESC p[XXRRGGBB]

const char *PreParseCombine(const struct FontStyleSpec *fss, const char *append)
{
    struct PreParseEntry *ppe;
    char buffer[MAX_PREPARSE_SPEC];
    size_t len;

    if (fss == NULL) {
        return append;
    }

    buffer[0] = 0;
    if (fss->fss_FrontColor >= 0) {
        sprintf(buffer, "\33P[%06lx]", (unsigned long)fss->fss_FrontColor);
    }
    if (fss->fss_BackColor >= 0) {
        sprintf(buffer + strlen(buffer), "\33p[%06lx]",
                (unsigned long)fss->fss_BackColor);
    }
    if (fss->fss_Style & FSF_UNDERLINED) {
        strcat(buffer, "\33u");
    }
    if (fss->fss_Style & FSF_BOLD) {
        strcat(buffer, "\33b");
    }
    if (fss->fss_Style & FSF_ITALIC) {
        strcat(buffer, "\33i");
    }
    if (fss->fss_Shadow) {
        strcat(buffer, "\33s");
    }
    if (fss->fss_Outline) {
        strcat(buffer, "\33t");
    }
    if (fss->fss_Glow) {
        strcat(buffer, "\33w");
    }
    if (fss->fss_Plain) {
        strcat(buffer, "\33n");
    }

    len = strlen(buffer);
    if (len == 0) {
        return append;
    }

    append = EmptyNullStr(append);
    FORNODE(ppe, &PreParseList) {
        if (strncmp(buffer, ppe->ppe_PreParse, len) == 0 &&
                strcmp(append, &ppe->ppe_PreParse[len]) == 0) {
            /* Put entry at head of list. */
            REMOVE(ppe);
            ADDHEAD(&PreParseList, ppe);
            return ppe->ppe_PreParse;
        }
    }

    ppe = PoolAllocMem(PreParseMemPool,
            sizeof(struct PreParseEntry) + len + strlen(append) + 1);
    if (ppe == NULL) {
        /* Fall back to plain preparse. */
        return append;
    }

    strcpy(ppe->ppe_PreParse, buffer);
    strcat(ppe->ppe_PreParse, append);
    ADDHEAD(&PreParseList, ppe);

    return ppe->ppe_PreParse;
}

