/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** buildgui.h
**
** Creation date: 11.12.1994
** Last modified: 03.04.2022
*/

#ifndef BUILD_GUI_H
#define BUILD_GUI_H

#include "system.h"
#include "display.h"
#include "lang/program.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifdef BEEBASE
#define MAIN_WINDOW_LOGO_IMAGE APP_NAME ":images/BeeBaseSplash.png"
#define MAIN_WINDOW_LOGO_BG_RED 0xb2
#define MAIN_WINDOW_LOGO_BG_GREEN 0x3f
#define MAIN_WINDOW_LOGO_BG_BLUE 0x40
#define MAIN_WINDOW_LOGO_BG_STR "b2b2b2b2,3f3f3f3f,40404040"
#define MAIN_WINDOW_LOGO_MIN_WIDTH 360
#define MAIN_WINDOW_LOGO_MIN_HEIGHT 240
#define MAIN_WINDOW_LOGO_DEFAULT_WIDTH 450
#define MAIN_WINDOW_LOGO_DEFAULT_HEIGHT 300
#else
#define MAIN_WINDOW_LOGO_IMAGE APP_NAME ":images/BeeOnHoneycomb.png"
#define MAIN_WINDOW_LOGO_BG_RED 0x37
#define MAIN_WINDOW_LOGO_BG_GREEN 0x37
#define MAIN_WINDOW_LOGO_BG_BLUE 0x37
#define MAIN_WINDOW_LOGO_BG_STR "37373737,37373737,37373737"
#define MAIN_WINDOW_LOGO_MIN_WIDTH 280
#define MAIN_WINDOW_LOGO_MIN_HEIGHT 160
#define MAIN_WINDOW_LOGO_DEFAULT_WIDTH 400
#define MAIN_WINDOW_LOGO_DEFAULT_HEIGHT 300
#endif

/* common structure for building field gui objects */
struct GuiFieldFeatures
{
    bool label, checkbox, button, image,
	choice, radiobuttons, editor, refpopup,
	text, listview, datatypes, show;
    bool readonly;
    char shortcut;
    int maxchars;
};

struct GuiDisplayObjectSizeConstraints
{
    bool can_grow_horiz;
    bool can_grow_vert;
};

bool BuildGuiFieldGetFeatures(struct DisplayObject *dio,
	struct GuiFieldFeatures *f);
bool BuildGuiFieldHasLabel(struct DisplayObject *dio);
void BuildGuiDisplayObjectGetSizeConstraints(struct DisplayObject *dio, bool horiz,
        struct GuiDisplayObjectSizeConstraints *constraints);
    
void FreeProjectGui(struct Project *pr);
bool BuildProjectGui(struct Project *pr);
bool BuildGuiWindow(struct DisplayObject *dio);        /* internal use */

void SetRootWindowTitle(struct Project *pr, GuiObject wi);
void BuildGuiAddRecord(struct Table *tab, struct Record *rec);
void BuildGuiRemRecord(struct Table *tab, struct Record *rec);
void BuildGuiRemAllRecords(struct Project *pr);

void GuiSetNumAll(GuiObject go, ulong num, ulong all);
void GuiSetString(GuiObject go, const char *str, bool readonly, GuiObject ext);
void GuiSetBoolean(GuiObject go, bool value, bool readonly);
void GuiSetChoice(GuiObject go, unsigned short value, char **labels,
        bool readonly);
void GuiSetMemo(GuiObject go, const char *str, bool readonly);
void GuiSetSFWList(GuiObject go, const struct Element *elem);
 
struct Record *GuiReferenceFieldQuickSearchRecord(struct DisplayObject *dio,
	GuiObject list, long dir, const char *search, struct Record *cur);

#ifdef __cplusplus
}
#endif

#endif

