/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** error.c:
**
** Creation date: 16.11.1994
** Last modified: 01.11.2020
*/

#include "system.h"
#include "appstrings_cat.h"
#include "error.h"

static CatalogString ErrorStrings[] =
{
    MSG_Err_Ok,
    MSG_Err_NotImplemented,
    MSG_Err_Internal,
    MSG_Err_Mem,
    MSG_Err_InvalidName,
    MSG_Err_NameAlreadyUsed,
    MSG_Err_NoTable,
    MSG_Err_UserCanceled,
    MSG_Err_SQLite3Message,
    MSG_Err_SQLite3Generic,
    MSG_Err_SQLite3IO,
    MSG_Err_CodesetInvalidUTF8,
    MSG_Err_CodesetConversion,
    MSG_Err_ProjectReadOnly,
    MSG_Err_ProjectReadLock,
    MSG_Err_ProjectChangeLock,
    MSG_Err_ProjectWriteLock,
    MSG_Err_ProjectVersion,
    MSG_Err_TableReference,
    MSG_Err_TableExactlyOneRecord,
    MSG_Err_InvalidMaxlen,
    MSG_Err_InitialValueLen,
    MSG_Err_InvalidInitialValue,
    MSG_Err_UnknownType,
    MSG_Err_MissingLabels,
    MSG_Err_NoReference,
    MSG_Err_InvalidReference,
    MSG_Err_NoSuchField,
    MSG_Err_FieldTypeNotAllowedForOrdering,
    MSG_Err_ObjectLevel,
    MSG_Err_GroupPanel,
    MSG_Err_CantBuildGui,
    MSG_Err_CantOpenMainWindow,
    MSG_Err_InitialRecord,
    MSG_Err_DeleteInitialRecord,
    MSG_Err_RecordExactlyOneRecord,
    MSG_Err_RecordNilValue,
    MSG_Err_RecordNotLocked,
    MSG_Err_NoProjectName,
    MSG_Err_OpenSwapFile,
    MSG_Err_ReadSwapFile,
    MSG_Err_OpenLogFile,
    MSG_Err_WriteLogFile,
    MSG_Err_OpenFile,
    MSG_Err_ReadFile,
    MSG_Err_WriteFile,
    MSG_Err_NoBeeBaseProject,
    MSG_Err_Version,
    MSG_Err_NoBeeBaseProject,
    MSG_Err_NotABeeBaseProject,
    MSG_Err_LockProject,
    MSG_Err_ProjectLocked,
    MSG_Err_Rename,
    MSG_Err_Delete,
    MSG_Err_ReadDir,
    MSG_Err_MkDir,
    MSG_Err_RmDir,
    MSG_Err_ChDir,
    MSG_Err_GetCwd,
    MSG_Err_NoSuchFieldOrTable,
    MSG_Err_PathFull,
    MSG_Err_PathComponent,
    MSG_Err_CompileProgram,
    MSG_Err_ExecuteQuery,
    MSG_Err_FieldInUse,
    MSG_Err_TableInUse,
    MSG_ProgErr_Trigger,
    MSG_ProgErr_Type,
    MSG_ProgErr_CompareTypes,
    MSG_ServErr_InvalidHandle,
    MSG_ServErr_BrokenConnection,
    MSG_ServErr_InTransaction,
    MSG_ServErr_NotInTransaction,
    MSG_ServErr_NestedTransaction,
    MSG_ARexxErr_ResultStringTooLong,
    MSG_ARexxErr_NoProject,
    MSG_ARexxErr_Busy,
};

char *GetErrorString(long error)
{
    if (error < 0 || error > NumErrCodes) {
	return (char *)GCS(MSG_Err_ErrorNum);
    } else {
	return (char *)GCS(ErrorStrings[error]);
    }
}

bool IsProjectError(long error)
{
    return (error >= PROJECTERR_READONLY && error <= PROJECTERR_VERSION);
}

bool IsProjectErrorString(const char *errstr)
{
    bool rc = FALSE;
    long err;

    for (err = PROJECTERR_READONLY; err <= PROJECTERR_VERSION; err++) {
        if (GES(err) == errstr) {
            rc = TRUE;
            break;
        }
    }

    return rc;
}

