/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** error.h
**
** Error codes
**
** Creation date: 24.03.1995
** Last modified: 01.11.2020
*/

#ifndef ERROR_H
#define ERROR_H

#ifdef __cplusplus
extern "C" {
#endif

enum ErrorCodes
{
    OK,                         /* No error */
    ERR_NOTIMPLEMENTED,         /* function not (yet) implemented */
    ERR_INTERNAL,               /* internal error */
    ERR_MEM,                    /* out of memory */
    ERR_INVALIDNAME,            /* invalid name */
    ERR_NAMEALREADYUSED,        /* Name in use */
    ERR_NOTABLE,                /* No table */
    ERR_CANCEL,                 /* User cancelled */
    SQLITEERR_MESSAGE,          /* SQLite3 error: %s */
    SQLITEERR_GENERIC,          /* SQLite3 error */
    SQLITEERR_IO,               /* SQLite3 I/O error */
    CODESETERR_INVALIDUTF8,	/* Invalid UTF8 sequence (currently unused) */
    CODESETERR_CONVERSION,	/* UTF8 conversion of characters failed */
    PROJECTERR_READONLY,        /* Project is read-only. */
    PROJECTERR_READLOCK,        /* Can't obtain read-lock on project. */
    PROJECTERR_CHANGELOCK,      /* Can't obtain change-lock on project. */
    PROJECTERR_WRITELOCK,       /* Can't obtain write-lock on project. */
    PROJECTERR_VERSION,         /* Project has been updated on file. */
    TABLEERR_REFERENCE,         /* table is referenced by an field */
    TABLEERR_EXACTLYONERECORD,  /* table already has more than one record */
    FIELDERR_INVALIDMAXLEN,
    FIELDERR_INITIALVALUELEN,
    FIELDERR_INVALIDINITIALVALUE,
    FIELDERR_UNKNOWNTYPE,
    FIELDERR_MISSINGLABELS,     /* for choice fields */
    FIELDERR_NOREFERENCE,       /* no reference for a reference field given. */
    FIELDERR_INVALIDREFERENCE,  /* tried to move reference to another table */
    ORDERR_UNKNOWNFIELD,        /* unknown field */
    ORDERR_FIELDTYPE,           /* field type not allowed for ordering. */
    DPYERR_OBJECTLEVEL,         /* for grouping objects */
    DPYERR_GROUPPANEL,
    DPYERR_BUILDGUI,            /* can't build project GUI */ 
    DPYERR_OPENGUI,             /* can't open project root window */ 
    RECERR_INITIALRECORD,       /* attempt to write on initial record */
    RECERR_DELETEINITIALRECORD, /* attempt to delete initial record */
    RECERR_EXACTLYONERECORD,    /* tried to allocate/free record in EOR table */
    RECERR_NILVALUE,            /* nil value not supported for this data type */
    RECERR_LOCK,                /* record not locked in RecordDataInfo call! */
    RECERR_NOPROJECTNAME,       /* no project name, save project first */
    RECERR_OPENSWAPFILE,        /* Can't open swap file! */
    RECERR_READSWAPFILE,        /* Can't read swap file */
    LOGERR_OPEN,                /* Can't open log file. */
    LOGERR_WRITE,               /* Error writing log file. */
    DISKERR_OPEN,               /* Can't open '%s' */
    DISKERR_READ,               /* Error reading '%s' */
    DISKERR_WRITE,              /* Error writing '%s' */
    DISKERR_TAG,                /* This is not a BeeBase project */
    DISKERR_VERSION,            /* wrong version */
    DISKERR_INVALID,            /* This is not a BeeBase project */
    DISKERR_NOTABEEBASEPROJECT, /* '%s' is not a BeeBase project */
    DISKERR_LOCK,               /* Can't lock file '%s' */
    DISKERR_LOCKED,             /* File '%s' locked by somebody else */
    DISKERR_RENAME,             /* Can't rename '%s' to '%s' */
    DISKERR_DELETE,             /* Can't delete '%s' */
    DISKERR_READDIR,            /* Can't read directory '%s' */
    DISKERR_MKDIR,              /* Can't create directory '%s' */
    DISKERR_RMDIR,              /* Can't delete directory '%s' */
    DISKERR_CHDIR,              /* Can't change to directory '%s' */
    DISKERR_GETCWD,             /* Can't get current directory */
    NAMEERR_TABLEFIELD,          /* no such field or table */
    NAMEERR_PATHFULL,           /* max number of path components reached */
    NAMEERR_PATHCOMPONENT,      /* path contains invalid path component */
    PROGERR_COMPILE,            /* Can't compile program */
    PROGERR_EXECUTE,            /* Error executing, %d %d (file %s): %s */
    PROGERR_FIELDINUSE,         /* Field is used in program */
    PROGERR_TABLEINUSE,         /* Table is used in program */
    PROGERR_TRIGGER,            /* Can't find trigger function */
    PROGERR_TYPE,               /* type error */
    PROGERR_COMPARETYPES,       /* Can't compare these types */
    SERVERR_HANDLE,             /* invalid handle */
    SERVERR_BROKENHANDLE,       /* broken connection */
    SERVERR_TRANSACTION,        /* in transaction */
    SERVERR_NOTRANSACTION,      /* not in a transaction */
    SERVERR_NESTEDTRANSACTION,  /* nested transaction */
    AREXXERR_RESULTTOOLONG,	/* result string too long */
    AREXXERR_NOPROJECT,		/* no such project */
    AREXXERR_BUSY,		/* application busy, try again later */
    NumErrCodes,
};

char *GetErrorString(long error);
#define GES(error)      GetErrorString(error)
/*
** Returns error string for an error number.
*/

bool IsProjectError(long error);
bool IsProjectErrorString(const char *errstr);

#ifdef __cplusplus
}
#endif

#endif

