/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** fileinfo.c
**
** Functions for creating & deleting .info files
**
** Creation date: 13.11.2004
** Last modified: 19.01.2009
*/

#include "fileinfo.h"
#include "project.h"
#include "strhandle.h"
#include "guidosutil.h"
#include "dosutil.h"
#include "memory.h"

#define ICON_TEMPLATE "BeeBase:icons/Project.info"

void AddFileInfo(struct Project *pr, const char *filename, bool force)
{
    if (filename) {
        struct MemPool *memPool = ProjectMemPool(pr);
	char *template = ExpandPathname(ICON_TEMPLATE, memPool);
	char *fileinfo;
	FILE *in, *out;
	int c;

        ProjectSetCurrentDir(NULL);    /* make sure we have correct CWD */
	if (template && FileStat(template) > 0) {
	    fileinfo = PoolAllocMem(memPool, strlen(filename) + 5 + 1);
	    if (fileinfo) {
		sprintf(fileinfo, "%s.info", filename);
		if (force || FileStat(fileinfo) < 0) {
		    in = FOpen(template, "rb");
		    if (in) {
			out = FOpen(fileinfo, "wb");
			if (out) {
			    while ((c = getc(in)) != EOF) {
				putc(c, out);
			    }
			    fclose(out);
			}
			fclose(in);
		    }
		}
		FreeString(memPool, fileinfo);
	    }
	}
	FreeString(memPool, template);
    }
}

void RemFileInfo(struct Project *pr, const char *filename)
{
    if (filename) {
        struct MemPool *memPool = ProjectMemPool(pr);
	char *fileinfo = PoolAllocMem(memPool, strlen(filename) + 1 + 4 + 1);

	if (fileinfo) {
            ProjectSetCurrentDir(NULL);    /* make sure we have correct CWD */
	    sprintf(fileinfo, "%s.info", filename);
	    RmFile(fileinfo);
	    FreeString(memPool, fileinfo);
	}
    }
}

