/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** project.h
**
** Creation date: 25.09.2014
** Last modified: 08.09.2015
*/

#ifndef FILE_LOCK_H
#define FILE_LOCK_H

#include "system.h"

typedef enum {
    NO_FILE_LOCK = 0,
    SHARED_FILE_LOCK,                /* many can read, no-one can write */
    RESERVED_FILE_LOCK,              /* many can read, one can write */
    EXCLUSIVE_FILE_LOCK              /* no-one can read, one can write */
} FileLockLevel;

struct FileLockContext;

struct FileLockContext *AllocFileLockContext(struct MemPool *memPool,
        const char *filename);
/*
** Allocates a locking context for the given filename.
*/

void FreeFileLockContext(struct FileLockContext *flc);

FileLockLevel CurrentFileLockLevel(struct FileLockContext *flc);
/* Returns the current file lock level */

long RaiseFileLockLevel(struct FileLockContext *flc, FileLockLevel level);
/*
** Raises the lock level to the given level.  If the lock is already at a higher
** level, does nothing.
*/

void ReleaseFileLockLevel(struct FileLockContext *flc); 
/*
** Releases all locks on the file.
*/

bool FileLockHasReservedLock(struct FileLockContext *flc);
/*
** Checks whether anyone has obtain a reserved lock on the file lock context.
*/

long ObtainCompatibilityFileLockLevel(struct FileLockContext *flc);
/*
** For compatibility with older projects, this obtains a lock equivalent to
** how BeeBase was locking projects in previous versions.  This first tries to
** obtain an exclusive lock, and if that fails, a shared lock.  Returns OK on
** success or an error code.  The actually obtained lock level can be queried
** by CurrentFileLockLevel.
*/

bool IsCompatibilityFileLockLevel(struct FileLockContext *flc);
/* Whether the file lock is a compatibility one */

#endif


