/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** labels.h
**
** Creation date: 01.05.1996
** Last modified: 04.01.2022
*/

#ifndef BASE_LABELS_H
#define BASE_LABELS_H

#include "memory.h"

#ifdef __cplusplus
extern "C" {
#endif

/*
** Labels are an array of strings terminated by a NULL pointer.
*/

size_t NumLabels(char **labels);
/* Counts the number of labels. */

void FreeLabelsNum(struct MemPool *memPool, char **labels, size_t num);
/* Frees all labels, there may be some NULL pointers in the string array */

void FreeLabels(struct MemPool *memPool, char **labels);
/* Frees all labels, no NULL pointers allowed */

char **AllocLabels(struct MemPool *memPool, size_t num);
/* Allocates label array and initializes each element with NULL. */

char **CopyLabels(struct MemPool *memPool, char **labels);
/* creates a copy of the given labels */

char **StringToLabels(struct MemPool *memPool, const char *str);
/* converts string to label array */

char *LabelsToString(struct MemPool *memPool, char **labels);
/* converts label array to string */

char **LoadLabels(struct MemPool *memPool, FILE *file, bool utf8, 
        long *error, size_t *warnings);
/* Loads labels from a file (internal format) */

#ifdef __cplusplus
}
#endif

#endif

