/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** memo.c
**
** Creation date: 27.02.1995
** Last modified: 16.05.2020
*/

#include "system.h"
#include "memo.h"
#include "codeset.h"
#include "util.h"
#include "memory.h"
#include "error.h"

char *MemoLineString(struct MemPool *memPool, const char *mi, long n, bool *err)
{
    char *str = NULL;
    
    if (err != NULL) {
        *err = FALSE;
    }

    if (mi != NULL) {
        const char *s = mi;
	long i = 0;

        while (i != n) {
            s = CodesetStrchr(s, '\n');
            if (s == NULL) {
                break;
            }
            s = CodesetNextChar(s);
            i++;
        }
        if (s != NULL) {
            const char *t = CodesetStrchr(s, '\n');
            size_t len = t == NULL ? strlen(s) : t - s;

            str = AllocStringN(memPool, s, len);
            if (str == NULL && err != NULL) {
                *err = TRUE;
            }
        }
    }
    return str;
}

long MemoNumLines(const char *mi)
{
    long num = 0;

    if (mi != NULL && mi[0] != 0) {
        num = StrCount(mi, '\n') + 1;
    }
    return num;
}

char *IndentMemo(const char *mi, long indent, struct MemPool *memPool)
{
    long num = MemoNumLines(mi);
    char *new = NULL;

    if (indent < 0) {
        indent = 0;
    }

    if (mi != NULL) {
        if (num <= 0) {
            new = AllocString(memPool, "");
        } else {
            new = PoolAllocMem(memPool, num * indent + strlen(mi) + 1);
            if (new != NULL) {
                const char *s = mi;
                char *t = new;

                do {
                    const char *n = CodesetStrchr(s, '\n');

                    if (n != NULL) {
                        n = CodesetNextChar(n);
                    }
                    sprintf(t, "%*s%.*s", (int)indent, "",
                            (int)(n == NULL ? strlen(s) : n - s), s);
                    s = n;
                    t += strlen(t);
                } while (s != NULL);
            }
        }
    }
    return new;
}

