/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** memo.h
**
** Creation date: 27.02.1995
** Last modified: 16.05.2020
*/

#ifndef MEMO_H
#define MEMO_H

#ifdef __cplusplus
extern "C" {
#endif

char *MemoLineString(struct MemPool *memPool, const char *mi, long n,
        bool *err);
/*
** returns the n-th line (beginning with 0) of the given memo.
** The return string will have no '\n' character at the end.
** The memory for the line string will be allocated from the given memPool.
** If n is out of range, NULL is returned and *err is set to FALSE.
** If n is in range and memory allocation has been successful
** then the line string is returned and *err is set to FALSE.
** If memory allocation fails, NULL is returned and *err is
** set to TRUE.
*/

long MemoNumLines(const char *mi);
/*
** Returns number of lines of the given memo.
*/

char *IndentMemo(const char *mi, long indent, struct MemPool *memPool);
/*
** Returns a new memo text where all lines have been indented by indent spaces.
** If indent is negative or if the memo is empty then nothing is indented and
** a copy of the memo is returned.
*/

#ifdef __cplusplus
}
#endif

#endif
