/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** menuprefs.c
**
** Functions for menu items in menu Preferences
**
** Creation date: 24.02.1996
** Last modified: 22.08.2020
*/

#include "system.h"
#include "preferences.h"
#include "menuprefs.h"
#include "requesters.h"
#include "setformats.h"
#include "appstrings_cat.h"

void MenuPrefsSetFormats(struct Project *pr)
{
    GuiSetFormats(pr);
}

void MenuPrefsSetExternalEditor(struct Project *pr)
{
    const char *externaleditor = GetPrefsString(pr, PREFS_EXTERNALEDITOR);

    externaleditor = AskString(pr, GCS(MSG_SetExternalEditor), GCS(MSG_Ok),
        externaleditor, 255, AST_FileSelect);

    if (externaleditor != NULL)
        SetPrefsString(pr, PREFS_EXTERNALEDITOR, externaleditor);
}

#ifdef USE_EXTERNALVIEWER
void MenuPrefsSetExternalViewer(struct Project *pr)
{
    const char *externalviewer = GetPrefsString(pr, PREFS_EXTERNALVIEWER);

    externalviewer = AskString(pr, GCS(MSG_SetExternalViewer), GCS(MSG_Ok),
        externalviewer, 255, AST_FileSelect);

    if (externalviewer != NULL)
        SetPrefsString(pr, PREFS_EXTERNALVIEWER, externalviewer);
}
#endif

void MenuPrefsExtraButtonsInTabChain(struct Project *pr, ulong checked)
{
    SetPrefsValue(pr, PREFS_EXTRABUTTONSINTABCHAIN, checked);
    GuiUpdateExtraButtonsInTabChain();
}

void MenuPrefsAdvanceOnEnter(struct Project *pr, ulong checked)
{
    SetPrefsValue(pr, PREFS_ADVANCEONENTER, checked);
}

void MenuPrefsConfirmQuit(struct Project *pr, ulong checked)
{
    SetPrefsValue(pr, PREFS_CONFIRMQUIT, checked);
}

void MenuPrefsConfirmDeleteRecord(struct Project *pr, ulong checked)
{
    SetPrefsValue(pr, PREFS_CONFIRMDELETERECORD, checked);
}

void MenuPrefsPathsRelativeToProject(struct Project *pr, ulong checked)
{
    SetPrefsValue(pr, PREFS_PATHSRELATIVETOPROJECT, checked);
    ProjectUpdateCurrentDir();
}

void MenuPrefsConfirmAutoReload(struct Project *pr, ulong checked)
{
    SetPrefsValue(pr, PREFS_CONFIRMAUTORELOAD, checked);
}

void MenuPrefsConfirmSaveReorg(struct Project *pr, ulong checked)
{
    SetPrefsValue(pr, PREFS_CONFIRMSAVEREORG, checked);
}

void MenuPrefsVacuumAfterReorg(struct Project *pr, ulong checked)
{
    SetPrefsValue(pr, PREFS_VACUUMAFTERREORG, checked);
}

void MenuPrefsSaveAsDefault(struct Project *pr)
{
    SetPrefsProjectDefaults(pr);
}

