/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** name.h
**
** Creation date: 20.11.1994
** Last modified: 04.08.2020
*/

#ifndef NAME_H
#define NAME_H

#include "project.h"

#ifdef __cplusplus
extern "C" {
#endif

#define MAX_TABLEFIELDPATH_COMPONENTS 8

struct RelFieldPath
{
    struct Table *rap_Relative;         /* Table to which path is relative to */
    bool rap_Star;                      /* star after name? */
    char rap_NumFields;
    struct Table *rap_Table;
    struct Field *rap_Fields[MAX_TABLEFIELDPATH_COMPONENTS];
};

bool IsMBName(const char *name);
/*
** Checks if name has valid syntax for a Table/Field name and
** if it's not a reserved key word.
*/

bool IsSystemName(const char *name);
/*
** Checks whether a name is a system one (internal name, e.g. for logging)
** Does not check whether the name also satisifies IsMBName.
*/

bool TableNameInUse(struct Project *pr, const char *name, struct Table *ignore);
/*
** Checks if the given name is already used by a table except Table ignore.
*/

bool FieldNameInUse(struct Table *tab, const char *name, 
	struct Field *ignore);
/*
** Checks if the given name is already used by an field in
** the specified Table except Field ignore.
*/

const char *NewFieldName(struct Field *field, const char *name);
const char *NewTableName(struct Table *tab, const char *name);
/*
** Checks name and returns new name.
*/

void NameSetUnknown(void *unknown);
/*
** Sets the Unknown pointer (either Table or Field)
** If a RelFieldPath contains a pointer to that Table/Field
** then PathNameToRelFieldPath returns NAMEERR_TABLEFIELD.
** This is useful for preparing Tables/Fields for deletion.
*/

long PathNameToRelFieldPath(struct Project *pr, struct Table *tab, 
	const char *name, struct RelFieldPath *rap);
/*
** Fills in the RelFieldPath structure. If tab != NULL then this table is used
** as tabative table.
** Returns 0 or error num
*/

const char *RelFieldPathToPathName(struct RelFieldPath *rap);
/*
** Constructs path name from a RelFieldPath.
*/

struct Field *RelFieldPathField(struct RelFieldPath *rap);
/*
** Returns last field of path or NULL if path does not
** contain any field.
*/

#ifdef __cplusplus
}
#endif

#endif

