/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** order.h
**
** Creation date: 30.04.1995
** Last modified: 21.07.2020
*/

#ifndef ORDER_H
#define ORDER_H

struct Order;

#include "table.h"

#ifdef __cplusplus
extern "C" {
#endif

struct OrderField
{
    bool oa_Ascending;
    struct Field *oa_Field;
};

long FieldCmp(struct Field *field, 
	const struct DataInfo *di1, const struct DataInfo *di2);

void FreeOrder(struct Order *ord);
void OrderRemField(struct Order *ord, struct Field *field);
long RecordCmp(struct Table *tab, struct Record *rec1, struct Record *rec2, 
	long *result);
/* returns error num or OK */

long ReorderRecords(struct Table *tab); /* returns error num or OK */
long ReorderAllRecords(struct Table *tab);
void ChangeOrder(struct Table *tab);

struct OrderField *GetOrderField(struct Table *tab, short num);
/* returns num-th order field */

char *GetOrderStr(struct MemPool *memPool, struct Table *tab);
long SetOrderStr(struct Table *tab, const char *orderstr);
/* returns error code or OK */

long LoadOrdersCustomFormat(struct Project *pr, FILE *file);

/* internal use only */

struct OrderData
{
    short od_Type;
    union
    {
	struct
	{
	    short num;
	    struct OrderField *oas;
	} fieldlist;
	char *cmpfunc;
    } od_Contents;
};

/* types */

#define ORD_TYPE_FIELDLIST 0
#define ORD_TYPE_CMPFUNC 1

long SetNewOrder(struct Table *tab, struct OrderData *od);

void GuiChangeOrder(struct Table *tab, struct OrderData *od);

#ifdef __cplusplus
}
#endif

#endif

