/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** pdfexport.h
**
** Creation date: 12.11.2011
** Last modified: 06.07.2021
*/

#ifndef PDFEXPORT_H
#define PDFEXPORT_H

#include "system.h"
#include "project.h"

#ifdef __cplusplus
extern "C" {
#endif

void GuiExportSFWListAsPDF(struct Project *pr, GuiObject sfw);

/* internal use only */

#ifdef USE_HPDF

#include <hpdf.h>

#define HPDF_FONT_SIZE_MIN 2.0
#define HPDF_FONT_SIZE_MAX 100.0

struct HPDFSettings
{
    HPDF_PageSizes hpdfs_PageSize;
    HPDF_PageDirection hpdfs_PageDirection;
    const char *hpdfs_FontName;
    HPDF_REAL hpdfs_FontSize;
    const char *hpdfs_Header;
    const char *hpdfs_Footer;
};

extern const HPDF_PageSizes HPDFPageSizes[];
extern const char *HPDFPaperNames[];
extern const HPDF_PageDirection HPDFPageDirections[];

void LoadHPDFSettingsFromPrefs(struct HPDFSettings *hpdfs, struct Project *pr);
void SaveHPDFSettingsToPrefs(const struct HPDFSettings *hpdfs,
        struct Project *pr);

const char *GetExportSFWListAsPDFStats(struct Project *pr, GuiObject sfw, 
        const struct HPDFSettings *hpdfs, long *pages, double *truncated);

bool ExportSFWListAsPDF(struct Project *pr, GuiObject sfw, 
        const struct HPDFSettings *hpdfs, const char *filename);

#endif

#ifdef __cplusplus
}
#endif

#endif

