/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** preferences.h
**
** Creation date: 27.03.1995
** Last modified: 06.07.2021
*/

#include "system.h"

#ifdef __cplusplus
extern "C" {
#endif

void PrefsInit(void);
void PrefsExit(void);

struct ProjectPrefs *AllocProjectPrefs(struct MemPool *memPool);
void FreeProjectPrefs(struct ProjectPrefs *pp);
void ClearProjectPrefs(struct ProjectPrefs *pp);

void SetPrefsValue(struct Project *pr, ulong item, long value);
bool SetPrefsString(struct Project *pr, ulong item, const char *string);
void SetPrefsWindowDimensions(struct Project *pr, ulong item,
        const struct WindowDimensions *wd);
void SetPrefsProjectDefaults(struct Project *pr);

long GetPrefsValue(struct Project *pr, ulong item);
const char *GetPrefsString(struct Project *pr, ulong item);
bool GetPrefsWindowDimensions(struct Project *pr, ulong item,
        struct WindowDimensions *wd);

char *GetProjectPrefsSettings(struct ProjectPrefs *pp, struct MemPool *memPool);
void SetProjectPrefsSettings(struct ProjectPrefs *pp, const char *settings);

long LoadProjectPrefsCustomFormat(struct ProjectPrefs *pp, FILE *in);

void LoadPrefs(void);
void SavePrefs(void);

/*
** Tag items, the order may be changed in accordance with preferences.c
*/

enum ProjectPrefsTags
{
    PREFS_CONFIRMDELETERECORD = 0,
    PREFS_RECORDMEMORY,
    PREFS_DEFAULTMAXLEN,
    PREFS_DEFAULTALIGNMENT_TEXT,
    PREFS_DEFAULTALIGNMENT_NUMBER,
    PREFS_PATHSRELATIVETOPROJECT,
    PREFS_CONFIRMAUTORELOAD,
    PREFS_CONFIRMSAVEREORG,
    PREFS_VACUUMAFTERREORG,
    PREFS_PROGRAMSOURCEEXTERNAL,
    PREFS_PROGRAMSOURCEEXTERNAL_FILENAME,
    PREFS_PROGRAMSOURCEEXTERNAL_CLEANUP,
    PREFS_PROGRAMSORTTRIGGERFUNCTIONS,
    PREFS_PROGRAMDEBUGINFO,
    PREFS_PROGRAMOBSOLETEFUNCTIONS,
    PREFS_PROGRAMINCLUDEDIR,
    PREFS_PROGRAMOUTPUT_FILENAME,
    PREFS_PROGRAMOUTPUT_DEFAULT,
    PREFS_PROGRAMOUTPUT_APPEND,
    PREFS_PROGRAMEDITOR_TOP,
    PREFS_PROGRAMEDITOR_POSX,
    PREFS_PROGRAMEDITOR_POSY,
    PREFS_QUERYDIR,
    PREFS_TEXTEDITOR_FILENAME,
    PREFS_LOG_ACTIVE,
    PREFS_LOG_TOPROJECT,
    PREFS_LOG_TOFILE,
    PREFS_LOG_FILENAME,
    PREFS_LOG_LABEL,
    NumProjectPrefsItems
};

/*
** Global tags, order must not be changed without changing preferences.c
*/

enum GlobalPrefsTags
{
    PREFS_PROJECTNAME = NumProjectPrefsItems,
    PREFS_REALFORMAT,
    PREFS_DATEFORMAT,
    PREFS_EXTERNALEDITOR,
#ifdef USE_EXTERNALVIEWER
    PREFS_EXTERNALVIEWER,
#else
    PREFS_UNUSED_EXTERNALVIEWER,
#endif
    PREFS_EXTRABUTTONSINTABCHAIN,
    PREFS_ADVANCEONENTER,
    PREFS_CONFIRMQUIT,
    PREFS_WARNCODESET,
    PREFS_HELPFILENAME,
    PREFS_EDITLABELSCOMPACT,
    PREFS_STRUCTUREEDITOR,
    PREFS_STRUCTUREEDITOR_LEFTEDGE = PREFS_STRUCTUREEDITOR,
    PREFS_STRUCTUREEDITOR_TOPEDGE,
    PREFS_STRUCTUREEDITOR_WIDTH,
    PREFS_STRUCTUREEDITOR_HEIGHT,
    PREFS_QUERYEDITOR,
    PREFS_QUERYEDITOR_LEFTEDGE = PREFS_QUERYEDITOR,
    PREFS_QUERYEDITOR_TOPEDGE,
    PREFS_QUERYEDITOR_WIDTH,
    PREFS_QUERYEDITOR_HEIGHT,
    PREFS_PROGRAMEDITOR,
    PREFS_PROGRAMEDITOR_LEFTEDGE = PREFS_PROGRAMEDITOR,
    PREFS_PROGRAMEDITOR_TOPEDGE,
    PREFS_PROGRAMEDITOR_WIDTH,
    PREFS_PROGRAMEDITOR_HEIGHT,
#ifdef USE_LOG_WINDOW
    PREFS_LOG_WINDOW,
    PREFS_LOG_WINDOW_LEFTEDGE = PREFS_LOG_WINDOW,
    PREFS_LOG_WINDOW_TOPEDGE,
    PREFS_LOG_WINDOW_WIDTH,
    PREFS_LOG_WINDOW_HEIGHT,
#endif
    PREFS_PDFSETTINGS_PAPERSIZE,
    PREFS_PDFSETTINGS_ORIENTATION,
    PREFS_HPDFSETTINGS_FONTNAME,
    PREFS_HPDFSETTINGS_FONTSIZE100,
    PREFS_QTPDFSETTINGS_FONTNAME,
    PREFS_PDFSETTINGS_HEADER,
    PREFS_PDFSETTINGS_FOOTER,
#ifdef USE_GTK_PRINT
    PREFS_GTKPRINTSETTINGS_FONTNAME,
    PREFS_GTKPRINTSETTINGS_FITPAGEWIDTH,
#endif
    NumPrefsItems
};

#ifdef __cplusplus
}
#endif

