/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** programeditor.h
**
** Creation date: 15.07.1995
** Last modified: 26.06.2008
*/

#ifndef PROGRAMM_EDITOR_H
#define PROGRAMM_EDITOR_H

#include "lang/program.h"

#ifdef __cplusplus
extern "C" {
#endif

GuiObject OpenProgramEditor(struct Project *pr);
/*
** Opens the program editor (if possible and not opened yet)
*/

void CloseProgramEditor(GuiObject obj);
/*
** Closes the program editor (if opened) silently.
*/

bool ProgramEditorCheckClose(GuiObject obj);
/*
** Checks if there are unsaved changes in the program editor.
** If so, prompts the user for confirmation to discard them.
** Returns FALSE if there are changes that should be saved.
*/

void ProgramEditorShowError(struct Project *pr, bool reload,
	const char *error, long line, long col, const char *filename);
/*
** Shows an error message to the user.  If the error is in the
** internal program (filename == NULL), opens the program editor
** (if possible and not opened yet) and places the cursor on the error
** If reload is TRUE, reloads the last compiled program after asking the
** user for permission.
*/

bool ProgramEditorFix(struct Project *pr);
/*
** Opens the program editor, compiles the program and waits until
** the user leaves the editor.
** Returns TRUE if the program has been compiled successfully.
*/

const char *ProgramEditorCompile(GuiObject pe, bool reload,
	struct Program **compiled, long *line, long *col, 
        const char **filename);
/* 
** (Re-)compiles program in an open program editor.
** If reload is TRUE, restores the editor contents with 
** the successfully compiled program (pretty print).
** On error, returns error string and sets line, col, and filename.
*/

const char *ProgramEditorCreateSourceExternal(GuiObject pe);
/*
** Saves the contents of the program editor to the external source file.
** Closes the program editor on success and returns NULL.
** Otherwise returns error message.
*/

#ifdef __cplusplus
}
#endif

#endif

