/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** recorddescription.h
**
** Creation date: 15.07.2012
** Last modified: 21.08.2012
*/

#ifndef RECORD_DESCRIPTION_H
#define RECORD_DESCRIPTION_H

#include "system.h"

#define RDS_TYPE_FIELDS 0
#define RDS_TYPE_COMPUTED 1
#define RDS_TYPE_INHERITED 2

#define RDS_FIELD_RECNUM ((struct Field *)12345)     /* -1 doesn't work */

#ifdef __cplusplus
extern "C" {
#endif

struct Table;
struct Record;

struct RecordDescription;

struct RecordDescriptionSpec
{
    short rds_Type;
    bool rds_MultiColumn;
    char *rds_Compute;
    short rds_NumFields;
    struct Field *rds_Fields[0];
};

struct RecordDescription *AllocRecordDescription(struct Table *tab,
        const struct RecordDescriptionSpec *rds);
void FreeRecordDescription(struct RecordDescription *rd);

void RecordDescriptionSetRecord(struct RecordDescription *rd, 
        struct Record *rec);

long RecordDescriptionError(struct RecordDescription *rd);
long RecordDescriptionNumColumns(struct RecordDescription *rd);
short RecordDescriptionColumnType(struct RecordDescription *rd, long col);
char *RecordDescriptionColumnText(struct RecordDescription *rd, long col,
        struct MemPool *memPool, bool *free);

char *RecordDescriptionText(struct RecordDescription *rd,
        struct MemPool *memPool, bool *free);

struct RecordDescriptionSpec *AllocRecordDescriptionSpec(
        struct MemPool *memPool, short numFields);
struct RecordDescriptionSpec *CopyRecordDescriptionSpec(
        struct MemPool *memPool, const struct RecordDescriptionSpec *orig);
void FreeRecordDescriptionSpec(struct MemPool *memPool, 
        struct RecordDescriptionSpec *rds);
bool RecordDescriptionSpecIsDefault(const struct RecordDescriptionSpec *rds);

#ifdef __cplusplus
}
#endif

#endif

