/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** search.h
**
** Creation date: 16.09.1996
** Last modified: 18.09.2006
*/

#ifndef SEARCH_H
#define SEARCH_H

#include "system.h"

struct Record;

#define PATTERN_SIZE 256

struct SearchFor
{
    struct Table *sf_Table;
    struct Field *sf_Field;
    char sf_Pattern[PATTERN_SIZE];
    bool sf_CaseSensitive;
    bool sf_AllFields;                  /* ignored if sf_Field is NULL */
    bool sf_Forward;
    bool sf_FirstLastRecord;
    bool sf_MatchFilter;
    struct Field *sf_MatchField; /* field that actually matched */
};

extern struct SearchFor SearchFor;

#ifdef __cplusplus
extern "C" {
#endif

struct SearchFor *GuiSearchFor(struct SearchFor *preset);
/*
** Pops up a dialog to enter a search string and returns
** pointer to SearchFor structure or NULL on cancel.
** preset must be != NULL. 
*/

const char *SearchRecord(struct SearchFor *sf, struct Record **prec, 
        struct Record *current);
/*
** Searches record.
*/

void ShowSearchRecord(struct SearchFor *sf);
/*
** Searches and displays record.
*/

#ifdef __cplusplus
}
#endif

#endif

