/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** status.c
**
** Creation date: 23.07.1995
** Last modified: 27.10.2020
*/

#include "system.h"
#include "main.h"
#include "status.h"
#include "project.h"
#include "log.h"
#include "table.h"
#include "field.h"
#include "display.h"
#include "menu.h"
#include "lang/program.h"

ulong GetStatus(GuiObject win)
{
    struct Project *pr = GuiWindowProject(win);
    ulong status = 0;
    ulong sleep = GuiSleep();
    ulong projectSleep = GuiProjectSleep(pr);
    struct DisplayObject *dio = NULL, *tabdio = NULL;
    struct Table *tab = NULL;
    struct Field *field;
    GuiObject go = GuiActiveObject(win);
    bool prun = ProgramRunning();

    if (sleep == 0 && projectSleep == 0 && !prun) {
        status |= STATUS_ACTIVE;
    }

/*  this is annoying when virtual fields are present
    if (prun)
        status |= STATUS_PROGRAM; */

    if (ProjectAdminMode(pr)) {
	status |= STATUS_ADMIN;
    }

    if (ProjectStructureEditor(pr) != NULL) {
        status |= STATUS_STRUCTUREEDITOR;
    } else {
        status |= STATUS_WORK;
    }

    if (!ProjectIsEmpty(pr)) {
	status |= STATUS_NONEMPTY;
    }

    dio = DisplayActiveObject(win);
    tab = DisplayObjectTable(dio);
    tabdio = TableDisplayObject(tab);
    if (!TableExactlyOneRecord(tab) && DisplayObjectVisible(tabdio) &&
            DisplayTableHasPanel(tabdio)) {
        status |= STATUS_ACTIVETABLE;
        if (DisplayTablePanelFilter(tabdio)) {
            status |= STATUS_HASFILTER;
	}
        if (DisplayTablePanelArrows(tabdio)) {
            status |= STATUS_HASARROWS;
	}
    }

    field = DisplayFieldField(dio);
    if (FieldType(field) == TYPE_REFERENCE) {
        status |= STATUS_ACTIVEREFERENCE;
    }

    if (GuiIsEditorObject(go)) {
        status |= STATUS_ACTIVEEDITOR;
    }

    if (ProjectChanges(pr) > 0) {
        status |= STATUS_HASCHANGES;
    }

    if (LogHasTable(ProjectLog(pr))) {
        status |= STATUS_HASLOG;
    }

    return status;
}

