/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** strhandle.h
**
** Creation date: 12.08.1995
** Last modified: 12.07.2012
*/

#ifndef STRHANDLE_H
#define STRHANDLE_H

struct StrHandle;

#include "memory.h"

#ifdef __cplusplus
extern "C" {
#endif

struct StrHandle *AllocStrHandle(struct MemPool *memPool);
void FreeStrHandle(struct StrHandle *sh);

char *StrHandleString(struct StrHandle *sh);
/*
** Returns pointer to string buffer.
** You have to copy string for further usage.
*/

bool StrHandleError(struct StrHandle *sh);
/* returns TRUE if an error has been occured (out of memory) */

bool StrHandlePutC(struct StrHandle *sh, char c);
bool StrHandlePutS(struct StrHandle *sh, const char *s);
/* returns TRUE on success, FALSE on error (out of memory) */

char *ReadString(FILE *file, struct MemPool *mp);
/* reads 0-terminated (raw) string from a file */
char *ReadStringConvert(FILE *file, bool utf8, struct MemPool *mp,
        long *err, size_t *warnings);
/* reads 0-terminated string from a file and converts it to a codeset string */

char *ExpandPathname(const char *path, struct MemPool *memPool);
/*
** Expands environment variables in path and returns
** new path name allocated from memPool.
*/ 

#ifdef __cplusplus
}
#endif

#endif

