/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** structureeditor
**
** Creation date: 10.11.1994
** Last modified: 06.08.2020
*/

#ifndef STRUCTUREEDITOR_H
#define STRUCTUREEDITOR_H

struct TableData;

#include "field.h"
#include "display.h"

#ifdef __cplusplus
extern "C" {
#endif

void GuiUserFunctionsQuickSearch(GuiObject go, int dir, const char *str);
bool TableSystemFilter(const struct Node *node);

#ifdef ENABLE_STRUCTURE_EDITOR
int DisplayNumCompareFunc(struct DisplayObject *d1, struct DisplayObject *d2);
int TableCompareAlpha(struct Table *tab1, struct Table *tab2);
int TableCompareDisplay(struct Table *tab1, struct Table *tab2);
int FieldCompareAlpha(struct Field *field1, struct Field *field2);
int FieldCompareDisplay(struct Field *field1, struct Field *field2);
void SortTablesAlpha(struct List *tabs);
void SortTablesDisplay(struct List *tabs);
void SortFieldsAlpha(struct List *fields);
void SortFieldsDisplay(struct List *fields);

long SE_NewTable(struct Project *pr, struct TableData *rd,
                    struct DisplayObject *dioparent, struct Table **tabp);
long SE_ChangeTable(struct Table *tab, struct TableData *rd);

void GuiChangeTable(GuiObject se, struct Table *tab);
bool GuiDeleteTable(struct Table *tab);

long SE_NewField(struct NewFieldData *nad, struct DisplayObject *dioparent,
        struct Field **fieldp);
long SE_ChangeField(struct ChangeFieldData *cad);

void GuiChangeField(GuiObject se, struct Field *field);
bool GuiDeleteField(struct Field *field);

void StructureEditorNextNameChange(struct Project *pr, void *lastChangeObject);
void StructureEditorSetNameChangeObject(GuiObject se, void *lastChangeObject);

void StructureEditor(struct Project *pr);
/* toggles between structure editor and database mode */

GuiObject OpenStructureEditor(struct Project *pr);

#endif

void CloseStructureEditor(GuiObject se);
void ClearStructureEditor(GuiObject se);
void StructureEditorUpdate(GuiObject se);
void StructureEditorCheckNames(struct Project *pr);

#ifdef __cplusplus
}
#endif

#endif
