/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** table.h
**
** Creation date: 15.11.1994
** Last modified: 28.07.2020
*/

#ifndef TABLE_H
#define TABLE_H

struct Table;
struct SQLiteTable;

#ifdef NEED_NODE_CAST
inline Table *nodecast(Table *, Node *node) { return (Table *)node; }
#endif

#include "display.h"
#include "field.h"
#include "record.h"
#include "system.h"

#define TABLE_TRIGGER_LEN FIELD_TRIGGER_LEN

#ifdef __cplusplus
extern "C" {
#endif

struct TableData
{
    const char *td_Name;		/* ASCII */
    bool td_System;
    bool td_ExactlyOneRecord;
    const char *td_NewTrigger;		/* ASCII */
    const char *td_DelTrigger;		/* ASCII */
    bool td_CountChanges;
    bool td_LogChanges;
};

struct ReadTableData
{
    long rtd_ID;
    const char *rtd_Name;		/* ASCII */
    bool rtd_ExactlyOneRecord;
    bool rtd_FilterActive;
    const char *rtd_NewTrigger;		/* ASCII */
    const char *rtd_DeleteTrigger;		/* ASCII */
    bool rtd_CountChanges;
    bool rtd_LogChanges;
    long rtd_GuiRecordID;
};

void FreeTable(struct Table *tab, bool quick);
struct Project *TableProject(struct Table *tab);
bool TableIsSystem(struct Table *tab);
struct SQLiteTable *TableSQLiteTable(struct Table *tab);
void SetTableSQLiteTable(struct Table *tab, struct SQLiteTable *sqlt);
struct List *TableFields(struct Table *tab);
long TableNumFields(struct Table *tab);
struct List *TableRecords(struct Table *tab);
struct MemPool *TableMemPool(struct Table *tab);
const char *TableName(struct Table *tab);
bool TableExactlyOneRecord(struct Table *tab);
struct Table *FindTableName(struct Project *pr, const char *name);
void SetTableDisplayObject(struct Table *tab, struct DisplayObject *dio);
struct DisplayObject *TableDisplayObject(struct Table *tab);
struct Record *TableGuiRecord(struct Table *tab);
void SetTableGuiRecord(struct Table *tab, struct Record *rec);
bool TableGuiFlag(struct Table *tab);
void SetTableGuiFlag(struct Table *tab, bool flag);
struct Record *TableProgramRecord(struct Table *tab);
void SetTableProgramRecord(struct Table *tab, struct Record *rec);
struct Program *TableFilterProgram(struct Table *tab);
void SetTableFilterProgram(struct Table *tab, struct Program *prg);
bool TableFilterActive(struct Table *tab);
void SetTableFilterActive(struct Table *tab, bool active);
struct Order *TableOrder(struct Table *tab);
void SetTableOrder(struct Table *tab, struct Order *ord);
struct TableRecordInfo *TableRecordInfo(struct Table *tab);
char *TableNewTrigger(struct Table *tab);
char *TableDelTrigger(struct Table *tab);
bool TableCountChanges(struct Table *tab);
bool TableLogChanges(struct Table *tab);

void AddField(struct Table *parent, struct Field *field, 
        struct Field *pred);
void RemField(struct Table *parent, struct Field *field);
void AddRecord(struct Table *tab, struct Record *rec, struct Record *pred);
/*
** special pred values:
*/
#define ADDRECORD_HEAD (struct Record *)NULL
#define ADDRECORD_TAIL (struct Record *)~0

void RemRecord(struct Table *tab, struct Record *rec);

long TableNumRecords(struct Table *tab);

long NewTable(struct Project *pr, struct TableData *rd, struct Table **newtab);
/* returns 0 or error code */
long ChangeTable(struct Table *tab, struct TableData *rd);
/* returns 0 or error code */
long DeleteTable(struct Table *tab);

long NumTables(struct Project *pr);  /* returns number of tables of a project */
long TableNum(struct Table *tab);
struct Table *FindTableNum(struct Project *pr, long find);
void SetTablesGuiRecords(struct Project *pr);
long ReadTable(struct Project *pr, const struct ReadTableData *data);
void UpdateTable(struct Table *tab, long guiRecordID);
long LoadTablesCustomFormat(struct Project *pr, FILE *file);

#ifdef __cplusplus
}
#endif

#endif

