/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** list.c
**
** general handling of lists and nodes
**
**
** Creation date: 21.09.95
** Last modified: 22.11.96
*/

#include "system.h"
#include "list.h"

#ifndef NULL
#define NULL (void *)0
#endif

void NewList(struct List *list)
{
    if(list != NULL)
    {
	list->lh_Head = (struct Node *)&list->lh_Tail;
	list->lh_Tail = NULL;
	list->lh_TailPred = (struct Node *)&list->lh_Head;
    }
} 

void AddTail(struct List *list, struct Node *node)
{
    if(list != NULL && node != NULL)
    {
	node->ln_Succ = (struct Node *)&list->lh_Tail;
	node->ln_Pred = list->lh_TailPred;
	list->lh_TailPred->ln_Succ = node;
	list->lh_TailPred = node;
    }
}

void AddHead(struct List *list, struct Node *node)
{
    if(list != NULL && node != NULL)
    {
	node->ln_Succ = list->lh_Head;
	node->ln_Pred = (struct Node *)&list->lh_Head;
	list->lh_Head->ln_Pred = node;
	list->lh_Head = node;
    }
}

void Insert(struct List *list, struct Node *node, struct Node *pred)
{
    if(pred == NULL)
	AddHead(list, node);
    else if(node != NULL)
    {
	node->ln_Succ = pred->ln_Succ;
	node->ln_Pred = pred;
	pred->ln_Succ->ln_Pred = node;
	pred->ln_Succ = node;
    }
}

void Remove(struct Node *node)
{
    if(node != NULL)
    {
	struct Node *pred = node->ln_Pred;
	struct Node *succ = node->ln_Succ;

	if(pred != NULL && succ != NULL)
	{
	    pred->ln_Succ = succ;
	    succ->ln_Pred = pred;
	}
    }
}

struct Node *RemHead(struct List *list)
{
    struct Node *node = NULL;

    if(list == NULL)
	return(NULL);

    node = HEAD(list);
    if(SUCC(node) == NULL)
	return(NULL);

    Remove(node);
    return(node);
}

struct Node *RemTail(struct List *list)
{
    struct Node *node = NULL;

    if(list == NULL)
	return(NULL);

    node = TAILPRED(list);
    if(PRED(node) == NULL)
	return(NULL);

    Remove(node);
    return(node);
}

