/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** list.h
**
** general handling of lists and nodes
**
**
** Creation date: 20.09.95
** Last modified: 22.11.96
*/

#ifndef LIST_H
#define LIST_H

#ifdef __cplusplus
extern "C" {
#endif

struct List
{
    struct Node *lh_Head;
    struct Node *lh_Tail;
    struct Node *lh_TailPred;
};

struct Node
{
    struct Node *ln_Succ;
    struct Node *ln_Pred;
};

#define MinNode Node

void NewList(struct List *list);
/* initializes the list structure to an empty list */

void Insert(struct List *list, struct Node *node, struct Node *pred);
/*
** inserts node into the list. If pred != NULL then the list pointer is
** ignored and the node is placed just behind pred.
*/

void AddTail(struct List *list, struct Node *node);
/* append the node to the end of the list */

void AddHead(struct List *list, struct Node *node);
/* inserts the node as first element of the list */

void Remove(struct Node *node);
/* removes the node */

struct Node *RemHead(struct List *list);
/*
** removes and returns first element of list,
** if list is empty NULL is returned.
*/

struct Node *RemTail(struct List *list);
/*
** removes and returns last element of list,
** if list is empty NULL is returned.
*/

#ifdef __cplusplus
}
#endif

#endif

