/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkeditlabels.h
**
** Creation date: 08.05.2005
** Last modified: 27.03.2016
**
** GtkEditLabels is a subclass of group class.
** It consits of a GtkTreeView for a displaying a list
** of labels, an entry field for editing a label,
** and buttons for adding, removing and sorting of labels.
*/

#ifndef GTK_EDIT_LABELS_H
#define GTK_EDIT_LABELS_H

#include "gtkgroup.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_EDIT_LABELS	(gtk_edit_labels_get_type ())
#define GTK_EDIT_LABELS(obj)	(G_TYPE_CHECK_INSTANCE_CAST((obj), \
	    GTK_TYPE_EDIT_LABELS, GtkEditLabels))
#define GTK_EDIT_LABELS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), \
	    GTK_TYPE_EDIT_LABELS, GtkEditLabelsClass))
#define GTK_IS_EDIT_LABELS(obj) 	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
	    GTK_TYPE_EDIT_LABELS))
#define GTK_IS_EDIT_LABELS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), \
	    GTK_TYPE_EDIT_LABELS))
#define GTK_EDIT_LABELS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), \
	    GTK_TYPE_EDIT_LABELS, GtkEditLabelsClass))

typedef struct _GtkEditLabels      GtkEditLabels;
typedef struct _GtkEditLabelsClass GtkEditLabelsClass;

struct _GtkEditLabels
{
  GtkGroup group;
  char **labels;
  GtkWidget *tree;
  GtkWidget *newb;
  GtkWidget *remb;
  GtkWidget *sortb;
  GtkWidget *entry;
  //bool d_Compact;
  //Object *d_Main;
};

struct _GtkEditLabelsClass
{
  GtkGroupClass parent_class;
};

GType	   gtk_edit_labels_get_type   (void) G_GNUC_CONST;
GtkWidget* gtk_edit_labels_new	      (void);
void       gtk_edit_labels_set_labels (GtkEditLabels 	*edit,
	                               char            **labels);
char **    gtk_edit_labels_get_labels (GtkEditLabels    *edit);
void       gtk_edit_labels_set_sortable (GtkEditLabels  *edit,
                                       gboolean          sortable);
gboolean   gtk_edit_labels_get_sortable (GtkEditLabels  *edit);

#ifdef __cplusplus
}
#endif

#endif

