/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkexteditor.h
**
** GtkTextView with additional menu items for loading, saving, 
** and external editor.
**
** Creation data: 19.04.2004
** Last modified: 31.03.2007
*/

#ifndef GTK_EXT_EDITOR_H
#define GTK_EXT_EDITOR_H

#include <gtk/gtk.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_EXT_EDITOR	(gtk_ext_editor_get_type ())
#define GTK_EXT_EDITOR(obj)	(G_TYPE_CHECK_INSTANCE_CAST((obj), \
	    GTK_TYPE_EXT_EDITOR, GtkExtEditor))
#define GTK_EXT_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), \
	    GTK_TYPE_EXT_EDITOR, GtkExtEditorClass))
#define GTK_IS_EXT_EDITOR(obj) 	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
	    GTK_TYPE_EXT_EDITOR))
#define GTK_IS_EXT_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), \
	    GTK_TYPE_EXT_EDITOR))
#define GTK_EXT_EDITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), \
	    GTK_TYPE_EXT_EDITOR, GtkExtEditorClass))

typedef struct _GtkExtEditor      GtkExtEditor;
typedef struct _GtkExtEditorClass GtkExtEditorClass;

struct _GtkExtEditor
{
  GtkTextView text_view;
  gint top;
};

struct _GtkExtEditorClass
{
  GtkTextViewClass parent_class;
  void (*load)(GtkExtEditor *editor);
  void (*save)(GtkExtEditor *editor);
  void (*external_editor)(GtkExtEditor *editor);
};

GType	   gtk_ext_editor_get_type     (void) G_GNUC_CONST;
GtkWidget* gtk_ext_editor_new	       (void);

gint gtk_ext_editor_get_top            (GtkExtEditor *editor);
void gtk_ext_editor_set_top            (GtkExtEditor *editor,
					gint          top);
void gtk_ext_editor_get_cursor         (GtkExtEditor *editor, 
                                        guint        *line, 
                                        guint        *col);
void gtk_ext_editor_set_cursor         (GtkExtEditor *editor,
					guint         line,
					guint         col);

#ifdef __cplusplus
}
#endif

#endif

