/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkextentry.h
**
** Extending GtkEntry to add cursor control for an attached list
** independent of the label text.
**
** Creation data: 12.05.2004
** Last modified: 12.05.2004
*/

#ifndef GTK_EXT_ENTRY_H
#define GTK_EXT_ENTRY_H

#include <gtk/gtk.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_EXT_ENTRY             (gtk_ext_entry_get_type ())
#define GTK_EXT_ENTRY(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_EXT_ENTRY, GtkExtEntry))
#define GTK_EXT_ENTRY_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_EXT_ENTRY, GtkExtEntryClass))
#define GTK_IS_EXT_ENTRY(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_EXT_ENTRY))
#define GTK_IS_EXT_ENTRY_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_EXT_ENTRY))
#define GTK_EXT_ENTRY_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_EXT_ENTRY, GtkExtEntryClass))

typedef struct _GtkExtEntry        GtkExtEntry;
typedef struct _GtkExtEntryClass   GtkExtEntryClass;

struct _GtkExtEntry
{
  GtkEntry entry;
  GtkTreeView *tree;
};

struct _GtkExtEntryClass
{
  GtkEntryClass    parent_class;
};


GType          gtk_ext_entry_get_type        (void) G_GNUC_CONST;
GtkWidget*     gtk_ext_entry_new             (void);
void           gtk_ext_entry_set_attached_tree_view (GtkExtEntry *entry,
	 				      GtkTreeView     *tree);
GtkTreeView*   gtk_ext_entry_get_attached_tree_view (GtkExtEntry   *entry);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* GTK_EXT_ENTRY_H */

