/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkextimage.h
**
** Allow to scale a pixbuf in a GtkImage
**
** Creation data: 30.04.2004
** Last modified: 22.05.2007
*/

#ifndef GTK_EXT_IMAGE_H
#define GTK_EXT_IMAGE_H

#include <gtk/gtk.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_EXT_IMAGE	(gtk_ext_image_get_type ())
#define GTK_EXT_IMAGE(obj)	(G_TYPE_CHECK_INSTANCE_CAST((obj), \
	    GTK_TYPE_EXT_IMAGE, GtkExtImage))
#define GTK_EXT_IMAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), \
	    GTK_TYPE_EXT_IMAGE, GtkExtImageClass))
#define GTK_IS_EXT_IMAGE(obj) 	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
	    GTK_TYPE_EXT_IMAGE))
#define GTK_IS_EXT_IMAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), \
	    GTK_TYPE_EXT_IMAGE))
#define GTK_EXT_IMAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), \
	    GTK_TYPE_EXT_IMAGE, GtkExtImageClass))

typedef struct _GtkExtImage      GtkExtImage;
typedef struct _GtkExtImageClass GtkExtImageClass;

struct _GtkExtImage
{
  GtkImage image;
  gboolean fixed;
  gboolean scaled;
  gboolean keep_aspect;
  GdkPixbuf *pixbuf;
};

struct _GtkExtImageClass
{
  GtkImageClass parent_class;
};

GType	   gtk_ext_image_get_type     	(void) G_GNUC_CONST;
GtkWidget* gtk_ext_image_new          	(void);

void       gtk_ext_image_set_from_pixbuf (GtkExtImage 	*image,
					  GdkPixbuf     *pixbuf);
GdkPixbuf *gtk_ext_image_get_pixbuf      (GtkExtImage   *image);
void       gtk_ext_image_set_fixed       (GtkExtImage   *image,
	                                  gboolean       fixed);
gboolean   gtk_ext_image_get_fixed       (GtkExtImage   *image);
void       gtk_ext_image_set_scaled      (GtkExtImage   *image,
	                                  gboolean       scaled);
gboolean   gtk_ext_image_get_scaled      (GtkExtImage   *image);
void       gtk_ext_image_set_keep_aspect (GtkExtImage   *image,
	                                  gboolean       keep_aspect);
gboolean   gtk_ext_image_get_keep_aspect (GtkExtImage   *image);

#ifdef __cplusplus
}
#endif

#endif

