/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkgroup.h
**
** Grouping of wigdets similar to MUI's Group class
**
** Creation data: 09.03.2004
** Last modified: 05.09.2012
*/

#ifndef GTK_GROUP_H
#define GTK_GROUP_H

#include <gtk/gtk.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_GROUP 		(gtk_group_get_type ())
#define GTK_GROUP(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), \
	    GTK_TYPE_GROUP, GtkGroup))
#define GTK_GROUP_CLASS(klass) 	(G_TYPE_CHECK_CLASS_CAST((klass), \
	    GTK_TYPE_GROUP, GtkGroupClass))
#define GTK_IS_GROUP(obj) 	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
	    GTK_TYPE_GROUP))
#define GTK_IS_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), \
	    GTK_TYPE_GROUP))
#define GTK_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), \
	    GTK_TYPE_GROUP, GtkGroupClass))

#define GTK_GROUP_DEFAULT_HORIZ_SPACING 4
#define GTK_GROUP_DEFAULT_VERT_SPACING 4

typedef struct _GtkGroup      GtkGroup;
typedef struct _GtkGroupClass GtkGroupClass;
typedef struct _GtkGroupChild GtkGroupChild;

struct _GtkGroup
{
  GtkContainer container;
  
  /*< public >*/
  GList *children;
  guint16 row_cols;
  gint16 horiz_spacing;
  gint16 vert_spacing;
  guint horiz:1;
  guint same_width:1;
  guint same_height:1;

  /*< private >*/
  gint *min_dim1;
#if GTK_MAJOR_VERSION > 2
  gint *nat_dim1;
#endif
  guint *weight1;
  gint max_min_dim1;
  gint max_min_dim2;
  guint weight1_total;
  guint weight2_total;
};

struct _GtkGroupClass
{
  GtkContainerClass parent_class;
};

struct _GtkGroupChild
{
  GtkWidget *widget;
  guint16 horiz_weight;
  guint16 vert_weight;
};

GType	   gtk_group_get_type	       (void) G_GNUC_CONST;
GtkWidget* gtk_group_new	       (gboolean horiz,
			                guint num_row_cols);
void	   gtk_group_add_child	       (GtkGroup     *group,
					GtkWidget    *child,
					guint        horiz_weight,
					guint        vert_weight);
void	   gtk_group_set_horiz         (GtkGroup    *group,
					gboolean     horiz);
gboolean   gtk_group_get_horiz         (GtkGroup    *group);
void	   gtk_group_set_columns       (GtkGroup    *group,
					guint        columns);
guint      gtk_group_get_columns       (GtkGroup    *group);
void	   gtk_group_set_rows          (GtkGroup    *group,
					guint        rows);
guint      gtk_group_get_rows          (GtkGroup    *group);
void	   gtk_group_set_horiz_spacing (GtkGroup    *group,
					gint         horiz_spacing);
void	   gtk_group_set_vert_spacing  (GtkGroup    *group,
					gint         vert_spacing);
void	   gtk_group_set_spacing       (GtkGroup    *group,
					gint         horiz_spacing,
					gint         vert_spacing);
gint	   gtk_group_get_horiz_spacing (GtkGroup    *group);
gint	   gtk_group_get_vert_spacing  (GtkGroup    *group);
void	   gtk_group_set_same_width    (GtkGroup    *group,
					gboolean      same_width);
void	   gtk_group_set_same_height   (GtkGroup     *group,
					gboolean      same_height);
void	   gtk_group_set_same_size     (GtkGroup     *group,
					gboolean      same_width,
					gboolean      same_height);
gboolean   gtk_group_get_same_width    (GtkGroup     *group);
gboolean   gtk_group_get_same_height   (GtkGroup     *group);
guint      gtk_group_get_total_horiz_weight (GtkGroup     *group);
guint      gtk_group_get_total_vert_weight  (GtkGroup     *group);

void	   gtk_group_query_child_packing(GtkGroup    *group,
					GtkWidget    *child,
					guint        *horiz_weight,
					guint        *vert_weight);
void	   gtk_group_set_child_packing (GtkGroup     *group,
					GtkWidget    *child,
					guint	      horiz_weight,
					guint	      vert_weight);

void       gtk_group_change_init       (GtkGroup     *group);
void       gtk_group_change_exit       (GtkGroup     *group);

#ifdef __cplusplus
}
#endif

#endif

