/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkpopeditlabels.h
**
** A button that when pressed pops up
** an EditLabels window for editing labels
**
** Creation data: 02.09.2005
** Last modified: 21.04.2016
*/

#ifndef GTK_POP_EDIT_LABELS_H
#define GTK_POP_EDIT_LABELS_H

#include <gtk/gtk.h>

struct MemPool;

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_POP_EDIT_LABELS             (gtk_pop_edit_labels_get_type ())
#define GTK_POP_EDIT_LABELS(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_POP_EDIT_LABELS, GtkPopEditLabels))
#define GTK_POP_EDIT_LABELS_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_POP_EDIT_LABELS, GtkPopEditLabelsClass))
#define GTK_IS_POP_EDIT_LABELS(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_POP_EDIT_LABELS))
#define GTK_IS_POP_EDIT_LABELS_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_POP_EDIT_LABELS))
#define GTK_POP_EDIT_LABELS_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_POP_EDIT_LABELS, GtkPopEditLabelsClass))

typedef struct _GtkPopEditLabels        GtkPopEditLabels;
typedef struct _GtkPopEditLabelsClass   GtkPopEditLabelsClass;

struct _GtkPopEditLabels
{
  GtkButton button;
  GtkWidget *window;
  GtkWidget *edit_labels;
  struct MemPool *memPool;
  char **labels;
};

struct _GtkPopEditLabelsClass
{
  GtkButtonClass    parent_class;
  gboolean (*accept)(GtkPopEditLabels *pop, char **labels, gpointer data);
};


GType          gtk_pop_edit_labels_get_type        (void) G_GNUC_CONST;
GtkWidget*     gtk_pop_edit_labels_new             (void);
void           gtk_pop_edit_labels_set_spec        (GtkPopEditLabels   *pop,
					            const gchar   *spec);
void           gtk_pop_edit_labels_set_labels      (GtkPopEditLabels   *pop,
		                                    char              **labels);
char **        gtk_pop_edit_labels_get_labels      (GtkPopEditLabels *pop);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* GTK_POP_EDIT_LABELS_H */

