/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkpopimage.h
**
** MUI's popimage class for gtk
**
** Creation data: 21.06.2005
** Last modified: 04.03.2015
*/

#ifndef GTK_POP_IMAGE_H
#define GTK_POP_IMAGE_H

#include <gtk/gtk.h>

#if (GTK_MAJOR_VERSION == 2) && !defined(GDK_DISABLE_DEPRECATED)
#define ENABLE_GDK_STIPPLED
#endif

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_POP_IMAGE             (gtk_pop_image_get_type ())
#define GTK_POP_IMAGE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_POP_IMAGE, GtkPopImage))
#define GTK_POP_IMAGE_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_POP_IMAGE, GtkPopImageClass))
#define GTK_IS_POP_IMAGE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_POP_IMAGE))
#define GTK_IS_POP_IMAGE_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_POP_IMAGE))
#define GTK_POP_IMAGE_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_POP_IMAGE, GtkPopImageClass))

#define GTK_POP_IMAGE_PATTERN      (1 << 0)
#define GTK_POP_IMAGE_COLOR        (1 << 1)
#define GTK_POP_IMAGE_EXTERNAL     (1 << 2)

#define GTK_POP_IMAGE_ALL          0xff

typedef struct _GtkPopImage        GtkPopImage;
typedef struct _GtkPopImageClass   GtkPopImageClass;

struct _GtkPopImage
{
  GtkButton button;
};

struct _GtkPopImageClass
{
  GtkButtonClass    parent_class;
};


GType          gtk_pop_image_get_type        (void) G_GNUC_CONST;
GtkWidget*     gtk_pop_image_new             (void);
void           gtk_pop_image_set_spec        (GtkPopImage   *pop_image,
					      const gchar   *spec);
G_CONST_RETURN gchar *gtk_pop_image_get_spec (GtkPopImage   *pop_image);
void           gtk_pop_image_set_types       (GtkPopImage   *pop_image,
                                              guint          types);
guint          gtk_pop_image_get_types       (GtkPopImage   *pop_image);

void           gtk_widget_set_bg_spec        (GtkWidget     *widget,
                                              const gchar   *spec);
#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* GTK_POP_IMAGE_H */

