/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkpopselection.h
**
** an implementation of MUI's popasl class for gtk+-2.0/3.0
**
** Creation date: 21.05.2004
** Last modified: 01.03.2015
*/

#ifndef GTK_POP_SELECTION_H
#define GTK_POP_SELECTION_H

/*
** As a subclass of GtkPopString class, GtkPopSelection can be used to pop up
** a selection box for choosing a file, or a font.
**
** Using this class, you don't need to worry about handling the 
** selection box.  It will automatically be opened when the popup
** button is pressed and update the corresponding string object
** when the user terminates the selection box. From the programmers
** point of view, all you have to do is to handle the string
** object contents.
*/

#include "gtkpopstring.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_POP_SELECTION	(gtk_pop_selection_get_type ())
#define GTK_POP_SELECTION(obj)	(G_TYPE_CHECK_INSTANCE_CAST((obj), \
	    GTK_TYPE_POP_SELECTION, GtkPopSelection))
#define GTK_POP_SELECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), \
	    GTK_TYPE_POP_SELECTION, GtkPopSelectionClass))
#define GTK_IS_POP_SELECTION(obj) 	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
	    GTK_TYPE_POP_SELECTION))
#define GTK_IS_POP_SELECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), \
	    GTK_TYPE_POP_SELECTION))
#define GTK_POP_SELECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), \
	    GTK_TYPE_POP_SELECTION, GtkPopSelectionClass))

typedef struct _GtkPopSelection      GtkPopSelection;
typedef struct _GtkPopSelectionClass GtkPopSelectionClass;

struct _GtkPopSelection
{
  GtkPopString pop;
  GType type;
  GtkFileChooserAction file_chooser_action;
};

struct _GtkPopSelectionClass
{
  GtkPopStringClass parent_class;
  gboolean (*start)(GtkPopSelection *pop, gpointer data);
  void (*stop) (GtkPopSelection *pop, gpointer data);
};

GType	          gtk_pop_selection_get_type           (void) G_GNUC_CONST;
GtkWidget*        gtk_pop_selection_new	               (void);
void              gtk_pop_selection_set_selection_type (GtkPopSelection *pop,
	                                                GType type);
GType             gtk_pop_selection_get_selection_type (GtkPopSelection *pop);
void              gtk_pop_selection_set_file_chooser_action (
                                                        GtkPopSelection *pop,
                                                        GtkFileChooserAction a);
GtkFileChooserAction gtk_pop_selection_get_file_chooser_action (
                                                        GtkPopSelection *pop);
GtkFileChooserDialog*   
                  gtk_pop_selection_get_file_chooser_dialog   
		                                       (GtkPopSelection *pop);
#if GTK_MAJOR_VERSION == 2
GtkFontSelectionDialog*
                  gtk_pop_selection_get_font_selection_dialog 
		                                       (GtkPopSelection *pop);
#else
GtkFontChooserDialog*
                  gtk_pop_selection_get_font_chooser_dialog 
		                                       (GtkPopSelection *pop);
#endif

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif
