/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkpopwidget.h
**
** an implementation of MUI's popobject class for gtk+-2.0
**
** Creation date: 01.06.2004
** Last modified: 08.11.2008
*/

#ifndef GTK_POP_WIDGET_H
#define GTK_POP_WIDGET_H

/*
** GtkPopWidget class takes any GtkWidget as parameter and uses it
** as popup. You can e.g. simply create a GtkTreeView widget with
** some entries and the GtkPopWidget class will create a window
** around it and display it when the user hits the popup button.
*/

#include "gtkpopstring.h"

#ifndef G_GNUC_MAY_ALIAS
#if     __GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 3)
#  define G_GNUC_MAY_ALIAS __field__((may_alias))
#else
#  define G_GNUC_MAY_ALIAS
#endif
#endif

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_POP_WIDGET	(gtk_pop_widget_get_type ())
#define GTK_POP_WIDGET(obj)	(G_TYPE_CHECK_INSTANCE_CAST((obj), \
	    GTK_TYPE_POP_WIDGET, GtkPopWidget))
#define GTK_POP_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), \
	    GTK_TYPE_POP_WIDGET, GtkPopWidgetClass))
#define GTK_IS_POP_WIDGET(obj) 	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
	    GTK_TYPE_POP_WIDGET))
#define GTK_IS_POP_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), \
	    GTK_TYPE_POP_WIDGET))
#define GTK_POP_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), \
	    GTK_TYPE_POP_WIDGET, GtkPopWidgetClass))

typedef struct _GtkPopWidget      GtkPopWidget;
typedef struct _GtkPopWidgetClass GtkPopWidgetClass;

struct _GtkPopWidget
{
  GtkPopString pop;
  G_GNUC_MAY_ALIAS GtkWidget *widget;
  GtkWidget *toplevel;
  guint light:1;
};

struct _GtkPopWidgetClass
{
  GtkPopStringClass parent_class;
  gboolean (*start)(GtkPopWidget *pop, gpointer data);
  void (*stop) (GtkPopWidget *pop, gpointer data);
};

GType	          gtk_pop_widget_get_type       (void) G_GNUC_CONST;
GtkWidget*        gtk_pop_widget_new	        (void);
void              gtk_pop_widget_set_widget 	(GtkPopWidget *pop,
	                                         GtkWidget    *widget);
GtkWidget*        gtk_pop_widget_get_widget 	(GtkPopWidget *pop);
void              gtk_pop_widget_set_light 	(GtkPopWidget *pop,
	                                         gboolean      light);
gboolean          gtk_pop_widget_get_light 	(GtkPopWidget *pop);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif

