/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtksfwview.h
**
** GtkSFWView is a subclass of GtkTreeView class.
** Its purpose is for displaying the contents of a program element.
**
** Creation data: 13.05.2004
** Last modified: 09.02.2022
*/

#ifndef GTK_SFW_VIEW_H
#define GTK_SFW_VIEW_H

#include <system.h>
#include <gtk/gtk.h>
#include <queryeditor.h>

struct MemPool;
struct Table;
struct Field;
struct Record;
struct Element;

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_SFW_VIEW             (gtk_sfw_view_get_type ())
#define GTK_SFW_VIEW(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_SFW_VIEW, GtkSFWView))
#define GTK_SFW_VIEW_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_SFW_VIEW, GtkSFWViewClass))
#define GTK_IS_SFW_VIEW(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_SFW_VIEW))
#define GTK_IS_SFW_VIEW_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_SFW_VIEW))
#define GTK_SFW_VIEW_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_SFW_VIEW, GtkSFWViewClass))

#define SFW_MAX_FIELDS 63

typedef struct
{
    GtkTreeView tree;
    GtkWidget *popupMenu;
    struct QueryGuiData *data;
    bool showTitles;
    bool checkboxes;
    signed char columnOrder[SFW_MAX_FIELDS + 1];
    int headerLines;
    int linesPerPage;
    int pangoHeight;
    int pangoGapWidth;
    int pangoWidths[SFW_MAX_FIELDS + 1];
//    unsigned char sort, sort2;
} GtkSFWView;

typedef struct
{
    GtkTreeViewClass    parentClass;
    void (*internalMoveDrop)(GtkSFWView *sfw, glong row, gpointer data);
} GtkSFWViewClass;

/* for drag and drop support */
extern const GtkTargetEntry gtk_sfw_view_target;

GType          gtk_sfw_view_get_type        (void) G_GNUC_CONST;
GtkWidget*     gtk_sfw_view_new             (void);
void           gtk_sfw_view_set_show_titles (GtkSFWView *sfw, 
	                                     gboolean show);
gboolean       gtk_sfw_view_get_show_titles (GtkSFWView *sfw);
void           gtk_sfw_view_set_checkboxes  (GtkSFWView *sfw, 
	                                     gboolean checkboxes);
gboolean       gtk_sfw_view_get_checkboxes  (GtkSFWView *sfw);

const char *   gtk_sfw_view_set_titles_body (GtkSFWView *sfw,
                                             const struct Element *titles,
                                             const struct Element *body);
const char *   gtk_sfw_view_set_element     (GtkSFWView *sfw,
	                                     const struct Element *elem);
void           gtk_sfw_view_set_string      (GtkSFWView *sfw,
	                                     const char *string);
void           gtk_sfw_view_set_selected    (GtkSFWView *sfw,
                                             const bool *selected);
void           gtk_sfw_view_get_selected    (GtkSFWView *sfw,
                                             bool *selected);
void           gtk_sfw_view_rem_record      (GtkSFWView *sfw,
	                                     const struct Record *rec);
void           gtk_sfw_view_rem_all_records (GtkSFWView *sfw);
void 	       gtk_sfw_view_get_entry       (GtkSFWView *sfw, 
					     GtkTreePath *path, 
	                                     GtkTreeViewColumn *column, 
                                             long *line,
	                                     long *col,
					     struct Field **field, 
					     struct Record **rec);

struct Record *gtk_sfw_view_get_active_record(GtkSFWView *sfw);

void           gtk_sfw_view_set_active_record(GtkSFWView *sfw,
                                             struct Record *rec);
struct Record *gtk_sfw_view_get_record      (GtkSFWView *sfw,
                                             long row);

guint          gtk_sfw_view_get_active_line (GtkSFWView *sfw);

void           gtk_sfw_view_set_active_line (GtkSFWView *sfw,
                                             guint lineNum);
gint           gtk_sfw_view_get_active_column(GtkSFWView *sfw);

const signed char *gtk_sfw_view_get_column_order(GtkSFWView *sfw);

const struct QueryLine *
	       gtk_sfw_view_get_iter_first  (GtkSFWView *sfw, 
	                                     GtkTreeIter *iter);
const struct QueryLine *
               gtk_sfw_view_iter_next       (GtkSFWView *sfw, 
	                                     GtkTreeIter *iter);
const struct QueryLine *
	       gtk_sfw_view_get_query_line  (GtkSFWView *sfw, 
	                                     GtkTreeIter *iter);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* GTK_SFW_VIEW_H */

