/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkGui.h
**
** Creation date: 21.03.2004
** Last modified: 06.02.2022
*/

#ifndef GTK_GUI_H
#define GTK_GUI_H

#include "system.h"
#include <libintl.h>

typedef const char *CatalogString;
#define GCS(ref) (gettext(ref))

struct _GtkWidget;

typedef struct _GtkWidget *GuiObject;
  
struct Project;
struct Field;
struct Element;
struct WindowDimensions;

#ifdef __cplusplus
extern "C" {
#endif

extern char DefaultRealFormat, DefaultDateFormat;

void CloseGui(void);
const char *OpenGui(int *pargc, char **argv);    
/* returns error string or NULL on success */

void GuiPrefsUpdated(void);

void GuiBeep(void);

#define GuiLanguage() "english"

void GuiAbout(void);

void GuiSendQuitMessage(void);

ulong GuiSleep(void);
void GuiSetSleep(bool sleep);
void GuiClearWindowSleep(GuiObject w);
ulong GuiProjectSleep(struct Project *pr);
void GuiSetProjectSleep(struct Project *pr, bool sleep);
void GuiBlockBusyPointer(GuiObject w, bool block);

char *GuiEditorText(GuiObject go, struct MemPool *memPool);
void GuiSetEditorText(GuiObject go, const char *str);
void GuiSetEditorChanged(GuiObject edit, bool changed);

void GuiSetRegisterPage(GuiObject go, long pos);
long GuiRegisterActivePage(GuiObject go);

struct Project *GuiWindowProject(GuiObject go);

bool GuiOpenWindow(GuiObject wi);
void GuiCloseWindow(GuiObject wi);

short GuiObjectWeight(GuiObject obj, bool horiz);
const char *GuiObjectHelpNode(GuiObject go);
GuiObject GuiObjectParent(GuiObject go);

void GuiSetWindowDimensions(GuiObject win, const struct WindowDimensions *wd);
bool GuiGetWindowDimensions(GuiObject win, struct WindowDimensions *wd);

struct Project *GuiActiveProject(void);
GuiObject GuiActiveWindow(void);
GuiObject GuiActiveObject(GuiObject wi);
bool GuiIsEditorObject(GuiObject go);

struct DisplayObject *GuiObjectDisplayObject(GuiObject go);

void GuiSetSelected(GuiObject go, bool selected);
void GuiSetEnabled(GuiObject go, bool enabled);
bool GuiGetEnabled(GuiObject go);
void GuiSetBackground(GuiObject go, const char *bg);
long GuiListActive(GuiObject go);
void *GuiListActiveEntry(GuiObject go);
long GuiSFWListActive(GuiObject go);
void GuiListSetActive(GuiObject go, long num);
void GuiSFWListSetActive(GuiObject go, long num);
long GuiListFindNode(GuiObject go, void *node);
void *GuiListNthEntry(GuiObject go, long num);
long GuiListNumEntries(GuiObject go);
char GuiSFWListNumColumns(GuiObject go);
const struct QueryFieldInfo *GuiSFWListFieldInfos(GuiObject go);
const signed char *GuiSFWListColumnOrder(GuiObject go);
const struct QueryLine *GuiSFWListQueryLine(GuiObject go, long row);
struct Table *GuiSFWListControlTable(GuiObject go);
struct Record *GuiSFWListActiveRecord(GuiObject go);
void GuiSFWListSetActiveRecord(GuiObject go, struct Record *rec);
struct Record *GuiSFWListRecord(GuiObject go, long row);

struct Project *GuiObjectProject(GuiObject go);

const char *GuiStringContents(GuiObject go);    // only for text input fields
const char *GuiObjectText(GuiObject go);        // also non-input, encoding

bool GuiWindowOpen(GuiObject wi);
void GuiActivateWindow(GuiObject wi);
void GuiWindowToFront(GuiObject wi);
void GuiSetActiveGuiObject(GuiObject wi, GuiObject go);
void GuiSetWindowTitle(GuiObject wi, const char *title);
void GuiSetPrependWindowTitle(GuiObject wi, const char *prepend);

void GuiUpdateProjects(void);
void GuiStoreEdits(void);

void GuiMainLoop(bool (*reallyQuit)(void));
bool GuiMainLoopIteration(void);

void GuiShowHelp(const char *section);

#define GuiUpdateExtraButtonsInTabChain()

#ifdef __cplusplus
}
#endif

#endif

