/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkUtil.h
**
** Creation date: 03.04.2004
** Last modified: 23.02.2015
*/

#ifndef GTK_UTIL_H
#define GTK_UTIL_H

#include <gtk/gtk.h>
#include <system.h>
#include <codeset.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
** C interface 
*/
    
bool GuiSetTooltip(GuiObject go, const char *help);
GuiObject GuiMakeTooltip(GuiObject go, const char *help);
void GuiSetHelpNode(GtkWidget *w, const char *help);

/* additional list functions */
void GuiSetListStoreLabels(GtkListStore *store, const char * const *labels);
char **GuiListStoreLabels(GtkTreeModel *model);
void GuiSetListStoreListWithFilter(GtkListStore *store, struct List *list,
        bool (*filter)(const struct Node *node));
void GuiSetListStoreList(GtkListStore *store, struct List *list);

void GuiListSetList(GuiObject tree, struct List *list);
void GuiListSetListWithFilter(GuiObject tree, struct List *list,
        bool (*filter)(const struct Node *node));
void GuiListGetList(GuiObject tree, struct List *list);
long GuiListFindEntry(GuiObject tree, void *entry);
void GuiListSetActiveNode(GuiObject tree, void *node);
void GuiListSetActiveEntry(GuiObject tree, void *entry);
void GuiListRemoveEntry(GuiObject tree, void *entry);

GtkWindow *GuiFindTransientWindow(GtkWidget *suggest);
void GuiSetDialogGeometryHints(GtkWidget *dialog, GtkWidget *group);
void GuiSetDialogButtonOrder(GtkWidget *dialog);
void GuiSetWindowProject(GuiObject go, struct Project *pr);
void GuiAddEntryCallbacks(GtkWidget *entry, GtkWidget *ok);

GuiObject GuiAnyOpenedWindow(void);

GuiObject GuiTreeView(gint columns, GType *types, GtkCellRenderer **cells,
	GtkTreeCellDataFunc *funcs, gboolean choice);
GuiObject GuiPointerTreeView(GtkTreeCellDataFunc func, gboolean checkboxes);
GuiObject GuiStringTreeView(gboolean choice);
GuiObject GuiStringMultiColumnTreeView(gint columns, gboolean checkboxes,
	const char *titles);

GuiObject GuiLabel(const char *label, GuiObject mnemonic, gfloat xalign);

GuiObject GuiSimpleButton(const char *lab, gboolean canDef);
GuiObject GuiPopButton(const char *icon_name);
GuiObject GuiPopButtonSetCWD(const char *icon_name, struct Project *pr);

const gchar *gtkEntryText(GuiObject go);
gboolean gtkToggleButtonActive(GuiObject go);
gint gtkComboBoxActive(GuiObject go);
gint gtkRadioBoxActive(GuiObject go);
gdouble gtkSpinButtonValue(GuiObject go);
gdouble gtkRangeValue(GuiObject go);

void GuiIgnoreWindowDelete(GtkWidget *win);
void GuiAddWindowCallbacks(GtkWidget *win, GtkWidget *cancel);

gchar *gtkExpandPathname(const gchar *path);

gchar *gtkExpandPathnameGetAssign(const gchar *path, 
	gchar **assignName, gchar **assignPath);

gchar *gtkUnexpandPathname(const gchar *fullPath, 
	const gchar *assignName, const gchar *assignPath);

gchar *gtkEscapeStr(const gchar *str);

#ifdef __cplusplus
}
#endif

#ifdef __cplusplus

//
// additional C++ interface
//

void GuiUtilInit();
void GuiUtilExit();

class GuiBusyCursor
{
public:
    GuiBusyCursor() { GuiSetSleep(true); }
    ~GuiBusyCursor() { GuiSetSleep(false); }
};

inline GuiObject GuiLabel(const char *label, GuiObject mnemonic=0)
{ return GuiLabel(label, mnemonic, 1.0); }

inline GuiObject GuiSimpleButton(const char *label)
{ return GuiSimpleButton(label, false); }

inline GuiObject GuiTreeView(gint columns, GType *types,
	GtkCellRenderer **cells, GtkTreeCellDataFunc *funcs)
{ return GuiTreeView(columns, types, cells, funcs, false); }
inline GuiObject GuiPointerTreeView(GtkTreeCellDataFunc func)
{ return GuiPointerTreeView(func, false); }
inline GuiObject GuiStringTreeView() { return GuiStringTreeView(false); }

GuiObject GuiComboBox(const char * const *labels, gint active=0);

gchar *GuiUnderline(const char *str, cschar shortcut, gboolean &use);

#endif

#endif

