/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** gtkimpl.h
**
** Creation date: 24.03.2004
** Last modified: 20.03.2022
*/

#ifndef GTK_IMPL_H
#define GTK_IMPL_H

#include "system.h"
#include <gtk/gtk.h>
#ifdef MACOSX
#include <gtkosxapplication.h>

extern GtkosxApplication *BeeBaseApp;
#endif

#define BEE_ICON_NAME "beebase-bee"
#define SELECT_FILE_ICON_NAME "document-open"
#if GTK_MAJOR_VERSION == 2 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 10)
#define SELECT_FONT_ICON_NAME "gtk-select-font"
#else
#define SELECT_FONT_ICON_NAME "preferences-desktop-font"
#endif

#if GTK_MAJOR_VERSION == 2
#define GUI_TYPE_FONT_CHOOSER_DIALOG GTK_TYPE_FONT_SELECTION_DIALOG
#else
#define GUI_TYPE_FONT_CHOOSER_DIALOG GTK_TYPE_FONT_CHOOSER_DIALOG
#endif

/* MUI like macros for building gui */

#define End NULL)
#define DialogObject gtk_widget_new(GTK_TYPE_DIALOG
#define WindowObject gtk_widget_new(GTK_TYPE_WINDOW
#define GroupObject gtk_widget_new(GTK_TYPE_GROUP
#define NotebookObject gtk_widget_new(GTK_TYPE_NOTEBOOK
#define ScrolledWindowObject gtk_widget_new(GTK_TYPE_SCROLLED_WINDOW
#define ViewportObject gtk_widget_new(GTK_TYPE_VIEWPORT
#define DrawingAreaObject gtk_widget_new(GTK_TYPE_DRAWING_AREA
#define PopSelectionObject gtk_widget_new(GTK_TYPE_POP_SELECTION
#define PopWidgetObject gtk_widget_new(GTK_TYPE_POP_WIDGET
#define PopImageObject gtk_widget_new(GTK_TYPE_POP_IMAGE
#define PopEditLabelsObject gtk_widget_new(GTK_TYPE_POP_EDIT_LABELS
#define ColorSelectionObject gtk_widget_new(GTK_TYPE_COLOR_SELECTION
#define TreeViewObject gtk_widget_new(GTK_TYPE_TREE_VIEW
#define EditLabelsObject gtk_widget_new(GTK_TYPE_EDIT_LABELS
#define SFWViewObject gtk_widget_new(GTK_TYPE_SFW_VIEW
#define FrameObject gtk_widget_new(GTK_TYPE_FRAME
#define AlignmentObject gtk_widget_new(GTK_TYPE_ALIGNMENT
#define LabelObject gtk_widget_new(GTK_TYPE_LABEL
#define ArrowObject gtk_widget_new(GTK_TYPE_ARROW
#define ProgressBarObject gtk_widget_new(GTK_TYPE_PROGRESS_BAR
#define ImageObject gtk_widget_new(GTK_TYPE_IMAGE
#define ExtImageObject gtk_widget_new(GTK_TYPE_EXT_IMAGE
#define EntryObject gtk_widget_new(GTK_TYPE_ENTRY
#define ExtEntryObject gtk_widget_new(GTK_TYPE_EXT_ENTRY
#define SpinButtonObject gtk_widget_new(GTK_TYPE_SPIN_BUTTON
#define TextViewObject gtk_widget_new(GTK_TYPE_TEXT_VIEW
#define ExtEditorObject gtk_widget_new(GTK_TYPE_EXT_EDITOR
#define ComboBoxObject gtk_widget_new(GTK_TYPE_COMBO_BOX
#define RadioBoxObject gtk_widget_new(GTK_TYPE_RADIO_BOX
#define ButtonObject gtk_widget_new(GTK_TYPE_BUTTON
#define ToggleButtonObject gtk_widget_new(GTK_TYPE_TOGGLE_BUTTON
#define RadioButtonObject gtk_widget_new(GTK_TYPE_RADIO_BUTTON
#define CheckButtonObject gtk_widget_new(GTK_TYPE_CHECK_BUTTON
#define SpaceObject gtk_widget_new(GTK_TYPE_GROUP
#define MenuBarObject gtk_widget_new(GTK_TYPE_MENU_BAR
#define MenuObject gtk_widget_new(GTK_TYPE_MENU
#define MenuItemObject gtk_widget_new(GTK_TYPE_MENU_ITEM
#define HandleBoxObject gtk_widget_new(GTK_TYPE_HANDLE_BOX
#define EventBoxObject gtk_widget_new(GTK_TYPE_EVENT_BOX

#if GTK_MAJOR_VERSION == 2
#define HScaleObject gtk_widget_new(GTK_TYPE_HSCALE
#define VScaleObject gtk_widget_new(GTK_TYPE_VSCALE
#define HSeparatorObject gtk_widget_new(GTK_TYPE_HSEPARATOR
#define VSeparatorObject gtk_widget_new(GTK_TYPE_VSEPARATOR
#define HPanedObject gtk_widget_new(GTK_TYPE_HPANED
#define VPanedObject gtk_widget_new(GTK_TYPE_VPANED
#else
#define HScaleObject gtk_widget_new(GTK_TYPE_SCALE, \
    "orientation", GTK_ORIENTATION_HORIZONTAL
#define VScaleObject gtk_widget_new(GTK_TYPE_SCALE, \
    "orientation", GTK_ORIENTATION_VERTICAL
#define HSeparatorObject gtk_widget_new(GTK_TYPE_SEPARATOR, \
    "orientation", GTK_ORIENTATION_HORIZONTAL
#define VSeparatorObject gtk_widget_new(GTK_TYPE_SEPARATOR, \
    "orientation", GTK_ORIENTATION_VERTICAL
#define HPanedObject gtk_widget_new(GTK_TYPE_PANED, \
    "orientation", GTK_ORIENTATION_HORIZONTAL
#define VPanedObject gtk_widget_new(GTK_TYPE_PANED, \
    "orientation", GTK_ORIENTATION_VERTICAL
#endif

#define VGroup GroupObject, "horiz", FALSE
#define HGroup GroupObject, "horiz", TRUE
#define VCenter(obj) VGroup, \
    	"spacing", 0, \
        "child", SpaceObject, End, \
	"child", (obj), "weight", 0, \
	"child", SpaceObject, End, \
	End
#define HCenter(obj) HGroup, \
    	"spacing", 0, \
        "child", SpaceObject, End, \
	"child", (obj), "weight", 0, \
	"child", SpaceObject, End, \
	End
#define Frame(label) FrameObject, \
	"label", (label), \
	"label-xalign", 0.5, \
    	"shadow-type", GTK_SHADOW_ETCHED_IN
#define GroupAlignment(hasLabel) AlignmentObject, \
	"xscale", 1.0, \
	"yscale", 1.0, \
	"left-padding", GTK_GROUP_DEFAULT_HORIZ_SPACING, \
	"right-padding", GTK_GROUP_DEFAULT_HORIZ_SPACING, \
	"top-padding", (hasLabel)? 0 : GTK_GROUP_DEFAULT_VERT_SPACING, \
	"bottom-padding", GTK_GROUP_DEFAULT_VERT_SPACING
#define ChildLabelWidget(label, widget) \
        "child", GuiLabel(label, widget, 1.0), "weight", 0, "child", widget

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/* redefine gdk_pixbuf loading functions */
GdkPixbuf* gdk_pixbuf_new_from_file_ext (const char *filename, GError **error);
GdkPixbufAnimation* gdk_pixbuf_animation_new_from_file_ext (const char
  *filename, GError **error);

#undef gdk_pixbuf_new_from_file
#undef gdk_pixbuf_animation_new_from_file
#define gdk_pixbuf_new_from_file(filename, error) \
	gdk_pixbuf_new_from_file_ext(filename, error)
#define gdk_pixbuf_animation_new_from_file(filename, error) \
	gdk_pixbuf_animation_new_from_file_ext(filename, error)

/* for gtk classes */
gchar *unicode(const char *message);

GtkWidget *GtkNewEditor(struct Project *pr, bool scrollbar,
        bool readOnly, bool fixedFont, GtkWidget **editorObject);

#ifdef __cplusplus
}
#endif
#endif

