/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** funcdate.c
**
** Creation date: 24.08.2004
** Last modified: 24.08.2004
*/

#include "funcdate.h"
#include "heap.h"
#include "stack.h"
#include "util.h"

void ProgDay(short numArgs)
{
    long date;
    bool nil = !PopDate2(&date);
    short day;

    if (nil)
    {
	PushNil();
    }
    else
    {
	DateToDayMonthYear(date, &day, NULL, NULL);
	PushInteger(day);
    }
}

void ProgMonth(short numArgs)
{
    long date;
    bool nil = !PopDate2(&date);
    short month;

    if (nil)
    {
	PushNil();
    }
    else
    {
	DateToDayMonthYear(date, NULL, &month, NULL);
	PushInteger(month);
    }
}

void ProgYear(short numArgs)
{
    long date;
    bool nil = !PopDate2(&date);
    short year;

    if (nil)
    {
	PushNil();
    }
    else
    {
	DateToDayMonthYear(date, NULL, NULL, &year);
	PushInteger(year);
    }
}

void ProgDateDMY(short numArgs)
{
    long day, month, year;
    bool nil1 = !PopInteger2(&day);
    bool nil2 = !PopInteger2(&month);
    bool nil3 = !PopInteger2(&year);
    long date;

    if (nil1 || nil2 || nil3)
    {
	PushNil();
    }
    else if (!DayMonthYearToDate(day, month, year, &date))
    {
	PushNil();
    }
    else
    {
	PushDate(date);
    }
}

void ProgMonthDays(short numArgs)
{
    long month, year;
    bool nil1 = !PopInteger2(&month);
    bool nil2 = !PopInteger2(&year);

    if (nil1 || !MONTH_VALID(month))
    {
	PushNil();
	return;
    }
    if (nil2)
    {
	year = 2001;		/* any non-leap year */
    } 
    else if (!YEAR_VALID(year))
    {
	PushNil();
	return;
    }

    PushInteger(MonthDays((short)month, (short)year));
}

void ProgYearDays(short numArgs)
{
    long year;
    bool nil = !PopInteger2(&year);

    if (nil || !YEAR_VALID(year))
    {
	PushNil();
    }
    else
    {
	PushInteger(YearDays((short)year));
    }
}

void ProgAddMonth(short numArgs)
{
    long date;
    bool nil1 = !PopDate2(&date);
    long months;
    bool nil2 = !PopInteger2(&months);

    if (nil1 || nil2)
    {
	PushNil();
    }
    else if (!DateAddMonth(date, months, &date))
    {
	PushNil();
    }
    else
    {
	PushDate(date);
    }
}

void ProgAddYear(short numArgs)
{
    long date;
    bool nil1 = !PopDate2(&date);
    long years;
    bool nil2 = !PopInteger2(&years);

    if (nil1 || nil2)
    {
	PushNil();
    }
    else if (!DateAddYear(date, years, &date))
    {
	PushNil();
    }
    else
    {
	PushDate(date);
    }
}

void ProgToday(short numArgs)
{
    PushDate(DateToday());
}

void ProgNow(short numArgs)
{
    PushTime(TimeNow());
}

