/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** funcio.h
**
** Creation date: 29.01.1996
** Last modified: 01.02.2009
*/

#ifndef FUNCIO_H
#define FUNCIO_H

#include "program.h"
#include "textfile.h"

#define PROGSTDOUT_VARNAME "stdout"

extern struct Element ProgStdOut;

void InitFileIO(struct Project *pr);
/*
** Initializes internal data structures.
*/

void ExitFileIO(void);
/*
** Closes opened files.
*/

TextFile *GetElementTextFile(struct Element *elem);
/*
** Returns file handle from file element. Opens file if not already done.
** Aborts execution if file could not be opened or is invalid.
** Returns NULL if element is NIL.
*/

TextFile *ProgOutputTextFile(void);
/*
** Calls GetElementTextFile(GetGlobalVar(PROGSTDOUT_VARNAME))
*/

/* Functions for programming BeeBase */
void ProgFOpen(short numArgs);
void ProgFClose(short numArgs);

void ProgFError(short numArgs);
void ProgFFlush(short numArgs);
void ProgFEof(short numArgs);
void ProgFSeek(short numArgs);
void ProgFTell(short numArgs);

void ProgFGetChar(short numArgs);
void ProgFGetChars(short numArgs);
void ProgFGetStr(short numArgs);
void ProgFGetMemo(short numArgs);

void ProgFPutChar(short numArgs);
void ProgFPutStr(short numArgs);
void ProgFPutMemo(short numArgs);

#endif

