/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** functable.h
**
** Creation date: 14.05.1995
** Last modified: 06.03.2022
*/

#ifndef FUNCTABLE_H
#define FUNCTABLE_H

#include "program.h"
#include "compile_impl.h"

struct FuncInfo
{
    const char *fi_Name;
    const short fi_Id;
    const short fi_MinArity;
    const short fi_MaxArity;
    bool fi_HasSideEffect;              /* TRUE if function has side effect */
    const char fi_Kind;                 /* See FIK_* defines */
    char fi_Type;
    const char *fi_ArgTypes;            /* specify NULL for any type */
    const char *(*fi_Check)(struct FuncInfo *fi, struct AppArgs *);
    void (*fi_Code)(short numArgs);
    struct FuncInfo *fi_HashFirst, *fi_HashNext;
};

enum
{
    FUNCID_EQ,
    FUNCID_NE,
    FUNCID_LT,
    FUNCID_LE,
    FUNCID_GT,
    FUNCID_GE,
    FUNCID_AND,
    FUNCID_OR,
    FUNCID_NOT,
    FUNCID_ADD,
    FUNCID_SUB,
    FUNCID_MUL,
    FUNCID_DIVREAL,
    FUNCID_DIVINT,
    FUNCID_MOD,
    FUNCID_LIKE,
    FUNCID_CONS,
    FUNCID_LIST,
    FUNCID_FIRST,
    FUNCID_REST,
    FUNCID_APPEND,
    FUNCID_REVERSE,
    FUNCID_PRINT,
    FUNCID_PROGN,
    FUNCID_LENGTH,
    FUNCID_IF,
    FUNCID_SETQ,
    FUNCID_NEW,
    FUNCID_DELETE,
    FUNCID_STR,
    FUNCID_MEMO,
    FUNCID_INT,
    FUNCID_REAL,
    FUNCID_DATE,
    FUNCID_TIME,
    FUNCID_STRP,
    FUNCID_MEMOP,
    FUNCID_INTP,
    FUNCID_REALP,
    FUNCID_DATEP,
    FUNCID_TIMEP,
    FUNCID_NULL,
    FUNCID_LISTP,
    FUNCID_CONSP,
    FUNCID_ONEPLUS,
    FUNCID_ONEMINUS,
    FUNCID_MIN,
    FUNCID_MAX,
    FUNCID_ABS,
    FUNCID_RANDOM,
    FUNCID_GC,
    FUNCID_PRINTF,
    FUNCID_SPRINTF,
    FUNCID_LAST,
    FUNCID_NTH,
    FUNCID_PROG1,
    FUNCID_FOPEN,
    FUNCID_FCLOSE,
    FUNCID_FPRINTF,
    FUNCID_SETLABELS,
    FUNCID_GETLABELS,
    FUNCID_SETCURSOR,
    FUNCID_SETWINDOWOPEN,
    FUNCID_EDIT,
    FUNCID_VIEW,
    FUNCID_EXIT,
    FUNCID_NEXT,
    FUNCID_RETURN,
    FUNCID_FERROR,
    FUNCID_FGETCHAR,
    FUNCID_FGETSTR,
    FUNCID_FGETMEMO,
    FUNCID_LEN,
    FUNCID_RIGHTSTR,
    FUNCID_LEFTSTR,
    FUNCID_MIDSTR,
    FUNCID_UPPER,
    FUNCID_LOWER,
    FUNCID_WORD,
    FUNCID_WORDS,
    FUNCID_CONCAT,
    FUNCID_CONCAT2,
    FUNCID_LINE,
    FUNCID_LINES,
    FUNCID_HALT,
    FUNCID_ERROR,
    FUNCID_FPUTCHAR,
    FUNCID_FPUTSTR,
    FUNCID_FPUTMEMO,
    FUNCID_EQSTAR,
    FUNCID_NESTAR,
    FUNCID_LTSTAR,
    FUNCID_LESTAR,
    FUNCID_GTSTAR,
    FUNCID_GESTAR,
    FUNCID_SETQSTAR,
    FUNCID_NEWSTAR,
    FUNCID_DELETESTAR,
    FUNCID_EDITSTAR,
    FUNCID_VIEWSTAR,
    FUNCID_FUNCALL,
    FUNCID_TRIMSTR,
    FUNCID_INDEXSTR,
    FUNCID_INDEXSTRSTAR,
    FUNCID_INDEXBRK,
    FUNCID_INDEXBRKSTAR,
    FUNCID_MAXLEN,
    FUNCID_MEMOTOLIST,
    FUNCID_LISTTOMEMO,
    FUNCID_FILLMEMO,
    FUNCID_TRUNC,
    FUNCID_ROUND,
    FUNCID_GETORDERSTR,
    FUNCID_SETORDERSTR,
    FUNCID_GETMATCHFILTER,
    FUNCID_SETMATCHFILTER,
    FUNCID_GETFILTERACTIVE,
    FUNCID_SETFILTERACTIVE,
    FUNCID_GETFILTERSTR,
    FUNCID_SETFILTERSTR,
    FUNCID_TABLENAME,
    FUNCID_FIELDNAME,
    FUNCID_GETDISABLED,
    FUNCID_SETDISABLED,
    FUNCID_ASKFILE,
    FUNCID_ASKDIR,
    FUNCID_ASKSTR,
    FUNCID_ASKINT,
    FUNCID_ASKCHOICE,
    FUNCID_ASKCHOICESTR,
    FUNCID_ASKOPTIONS,
    FUNCID_ASKBUTTON,
    FUNCID_ASKMULTI,
    FUNCID_MAPFIRST,
    FUNCID_SORTLIST,
    FUNCID_SORTLISTGT,
    FUNCID_TODAY,
    FUNCID_NOW,
    FUNCID_CHANGES,
    FUNCID_SYSTEM,
    FUNCID_STAT,
    FUNCID_RECNUM,
    FUNCID_RECORDS,
    FUNCID_RECORD,
    FUNCID_FORMATMEMO,
    FUNCID_INDENTMEMO,
    FUNCID_GETWINDOWDISABLED,
    FUNCID_SETWINDOWDISABLED,
    FUNCID_RECP,
    FUNCID_COPYREC,
    FUNCID_GETWINDOWOPEN,
    FUNCID_SETMIDSTR,
    FUNCID_INSMIDSTR,
    FUNCID_FGETCHARS,
    FUNCID_ASC,
    FUNCID_CHR,
    FUNCID_MESSAGE,
    FUNCID_REMCHARS,
    FUNCID_REPLACESTR,
    FUNCID_REPLACESTRSTAR,
    FUNCID_FFLUSH,
    FUNCID_COMPLETE,
    FUNCID_PROJECTNAME,
    FUNCID_TACKON,
    FUNCID_FILENAME,
    FUNCID_DIRNAME,
    FUNCID_DELETEALL,
    FUNCID_CMP,
    FUNCID_CMPSTAR,
    FUNCID_GETISSORTED,
    FUNCID_SETISSORTED,
    FUNCID_REORDER,
    FUNCID_REORDERALL,
    FUNCID_RINDEXSTR,
    FUNCID_RINDEXSTRSTAR,
    FUNCID_RINDEXBRK,
    FUNCID_RINDEXBRKSTAR,   
    FUNCID_COPYSTR, 
    FUNCID_FEOF,
    FUNCID_FSEEK,
    FUNCID_FTELL,
    FUNCID_SETVIRTUALLISTACTIVE,
    FUNCID_GETVIRTUALLISTACTIVE,
    FUNCID_DAY,
    FUNCID_MONTH,
    FUNCID_YEAR,
    FUNCID_DATEDMY,
    FUNCID_MONTHDAYS,
    FUNCID_YEARDAYS,
    FUNCID_ADDMONTH,
    FUNCID_ADDYEAR,
    FUNCID_APPLY,
    FUNCID_SYSTEMSTAR,
    FUNCID_COMPLETEMAX,
    FUNCID_COMPLETEADD,
    FUNCID_STRTOLIST,
    FUNCID_LISTTOSTR,
    FUNCID_GETADMINMODE,
    FUNCID_SETADMINMODE,
    FUNCID_ADMINPASSWORD,
    FUNCID_SHA1SUM,
    FUNCID_PUBSCREEN,
    FUNCID_LOG,
    FUNCID_EXP,
    FUNCID_SQRT,
    FUNCID_POW,
    FUNCID_SETBGPEN,
    FUNCID_FIELD,
    FUNCID_FIELDS,
    FUNCID_PREPARECHANGE,
    FUNCID_MINSTAR,
    FUNCID_MAXSTAR,
    FUNCID_SETQLIST,
    FUNCID_SETQLISTSTAR,
    FUNCID_MOVEREC,
    FUNCID_GETREC,
    FUNCID_SETREC,
    FUNCID_REPLACENTH,
    FUNCID_REPLACENTHSTAR,
    FUNCID_MOVENTH,
    FUNCID_MOVENTHSTAR,
    FUNCID_REMOVENTH,
    FUNCID_REMOVENTHSTAR,
    NumFuncIds
};

/* special arities */
#define FIA_ANY -1

/* FuncInfo kinds */
#define FIK_EXPR 0      /* regular expression */
#define FIK_SETQ 1      /* SetQ-style for changing data */
#define FIK_SETQLIST 2  /* SetQList-style for changing data */
#define FIK_CONTROL 3   /* Program and database control */

struct ConstInfo
{
    char *ci_Name;
    short ci_Id;
    struct Element ci_Element;
    struct ConstInfo *ci_HashFirst, *ci_HashNext;
};

enum
{
    CONSTID_NIL,
    CONSTID_TRUE,
    CONSTID_RESET,
    CONSTID_NLQON,
    CONSTID_NLQOFF,
    CONSTID_ELITEON,
    CONSTID_ELITEOFF,
    CONSTID_NORMAL,
    CONSTID_BFON,
    CONSTID_BFOFF,
    CONSTID_ITON,
    CONSTID_ITOFF,
    CONSTID_ULON,
    CONSTID_ULOFF,
    CONSTID_WIDEON,
    CONSTID_WIDEOFF,
    CONSTID_CONDON,
    CONSTID_CONDOFF,
    CONSTID_INT_MAX,
    CONSTID_INT_MIN,
    CONSTID_HUGE_VAL,
    CONSTID_PI,
    CONSTID_OSVER,
    CONSTID_OSREV,
    CONSTID_LANGUAGE,
    CONSTID_MBVER,
    CONSTID_MBREV,
    CONSTID_SEEK_SET,
    CONSTID_SEEK_CUR,
    CONSTID_SEEK_END,
    CONSTID_OSTYPE,
    CONSTID_PEN_WHITE,
    CONSTID_PEN_BLACK,
    CONSTID_PEN_RED,
    CONSTID_PEN_GREEN,
    CONSTID_PEN_BLUE,
    CONSTID_PEN_CYAN,
    CONSTID_PEN_MAGENTA,
    CONSTID_PEN_YELLOW,
    CONSTID_TMPDIR,
    NumConstIds,
};

struct Field *ExprField(struct Expr *expr);
/* returns Field of given expr or NULL if not an Field expression */

short GenType(short type1, short type2);
/* returns generic type of type1 and type2 or NOTYPE if the types don't fit together */

struct FuncInfo *FindFuncInfoName(char *name);
struct FuncInfo *FindFuncInfoId(short id);

struct ConstInfo *FindConstInfoName(char *name);
struct ConstInfo *FindConstInfoId(short id);

#endif

