/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** global.c
**
** Creation date: 14.01.96
** Last modified: 03.05.98
*/

#include "system.h"
#include "dbtypes.h"
#include "compile_impl.h"
#include "program.h"
#include "programbin.h"
#include "heap.h"
#include "stack.h"
#include "funcio.h"
#include "global.h"
#include "appstrings_cat.h"
#include "memory.h"

struct GlobalVar
{
    char *gv_Name;
    struct Element *gv_Element;
};

static struct GlobalVar globalVars[] =
{
    { PROGSTDOUT_VARNAME, &ProgStdOut },
};
#define NUMGLOBALVARS (sizeof(globalVars) / sizeof(struct GlobalVar))

const char *BuildLocalIdentList(struct MemPool *memPool, 
        struct LocalIdent **defList)
{
    struct LocalIdent **pred = defList, *li;
    struct GlobalVar *gv;
    short i;

    if(defList == NULL)
        return(GCS(MSG_Err_Internal));

    for(i=0, gv = globalVars; i < NUMGLOBALVARS; i++, gv++)
    {
        li = PoolAllocMem(memPool, sizeof(struct LocalIdent));
        if(li == NULL)
            return(GCS(MSG_Err_Mem));

        *pred = li;
        li->LineCol.Line = 1;
        li->LineCol.Col = 1;
        li->Name = gv->gv_Name;
        li->Type = TYPE_UNKNOWN;
        li->Arity = -1;
        li->Pos = 0;                    /* will be set by StartToBin */
        li->Table = NULL;
        li->UserFunction = NULL;
        li->Next = NULL;
        pred = &li->Next;
    }

    *pred = NULL;
    return(NULL);
}

void PushGlobalVars(void)
{
    short i;
    struct GlobalVar *gv;
    struct Element *elem;

    for(i=0, gv = globalVars; i < NUMGLOBALVARS; i++, gv++)
        if(gv->gv_Element != NULL)
        {
            elem = MakeElement(TYPE_NIL, FALSE);
            *elem = *gv->gv_Element;
            StackPush(elem);
        }
        else
            PushNil();
}

struct Element *GetGlobalVar(char *name)
{
    struct GlobalVar *gv;
    short i;

    if(name != NULL)
        for(i=0, gv = globalVars; i < NUMGLOBALVARS; i++, gv++)
            if(strcmp(gv->gv_Name, name) == 0)
                return(StackNth(-1 - i));

    ExecuteAbort(GCS(MSG_Err_Internal));
    return(NULL);                       /* will never be executed */
}

