/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** programbin_impl.h
**
** Creation date: 20.04.1995
** Last modified: 13.05.2022
*/

#ifndef PROGRAMBIN_IMPL_H
#define PROGRAMBIN_IMPL_H

#include "programbin.h"
#include "compile_impl.h"

enum
{
    BIN_MKINTEGER,
    BIN_MKREAL,
    BIN_MKSTRING,
    BIN_MKDATE,
    BIN_MKTIME,
    BIN_MKTRUE,
    BIN_MKNIL,
    BIN_GETGLOBALDATA,
    BIN_GETLOCALDATA,
    BIN_GETLOCALEXTEND,
    BIN_CALLFUNC,
    BIN_PRESFW,
    BIN_SFW,
    BIN_FORALL_JMP,
    BIN_POSTSFW,
    BIN_POP,
    BIN_POPN,
    BIN_POP1N,
    BIN_SETGLOBALIDENT,
    BIN_SETLOCALIDENT,
    BIN_SETLOCALEXTEND,
    BIN_PUSHTOP,
    BIN_SETQLIST_NEXT,
    BIN_SETQLIST_END,
    BIN_JMPAND,
    BIN_JMPOR,
    BIN_JMPNIL,
    BIN_JMPTRUE,
    BIN_JMPGLOBALVAR,           /* for global variable initialization */
    BIN_JMP,
    BIN_POPJMP,                 /* for EXIT, NEXT and RETURN */
    BIN_POP1JMP,                /* for EXIT, NEXT and RETURN */
    BIN_JSR,
    BIN_RTS,
    BIN_DOTIMES_INIT,
    BIN_DOTIMES_STEP,
    BIN_DOTIMES_TEST,
    BIN_DOLIST_INIT,
    BIN_DOLIST_STEP,
    BIN_DOLIST_TEST,
    BIN_CASECMP,
    BIN_INITRUNTRIGGER,
    BIN_EXITRUNTRIGGER,
    BIN_INITGETVIRTUAL,
    BIN_INITGETVIRTUALEXTEND,
    BIN_EXITGETVIRTUAL,
    BIN_INITGETENABLED,
    BIN_EXITGETENABLED,
    BIN_INITGETTITLE,
    BIN_EXITGETTITLE,
    BIN_CONST,
    BIN_FUNCINFO,
    BIN_USERFUNCTION,
    BIN_TABLE,
    BIN_FIELD,
    BIN_FIELDEXTEND,
    BIN_INFO,
    BIN_END = 127,
};

struct SubProgram
{
    struct Bin *sp_Bin;
    long sp_Index;
};

struct UserGlobalVar
{
    struct MinNode ugv_Node;
    char *ugv_Name;
    struct Element *ugv_Element;
    struct Element *ugv_Garbage;
    long ugv_Stack;
};

struct UserFunction
{
    struct MinNode uf_Node;
    char *uf_Name;
    char uf_Type;
    short uf_Arity;
    char *uf_Types;
    bool uf_Trigger;
    bool uf_Visited;		/* for building dependencies */
    struct LineCol uf_LineCol;
    struct Bin *uf_Bin;
    struct SubProgram uf_SubProgram;
};

struct DisplayDependencies
{
    struct MinNode dd_Node;
    struct DisplayObject *dd_Object;
    short dd_Type;              /* see below */
    bool dd_Visited;		/* for building dependencies & updating field */
    struct List dd_Dependencies;
};

/* types */
enum {
    DD_TYPE_VIRTUALFIELD,
    DD_TYPE_ENABLED,
    DD_TYPE_TITLE,
};

struct Dependency
{
    struct MinNode dep_Node;
    void *dep_Pointer;
    short dep_Type;		/* see below */
};

enum
{
    DEP_TYPE_USERGLOBALVAR,
    DEP_TYPE_FIELD,
    DEP_TYPE_GUIOBJECT,
    DEP_TYPE_TABLE,
    DEP_TYPE_GUIRECORD,
    DEP_TYPE_PROJECT,
};

struct Bin
{
    struct MemPool *bin_MemPool;
    bool bin_HasDebugInfo;      /* TRUE if (line, col) info present */
    long bin_Size;              /* buffer size */
    long bin_Len;               /* buffer valid contents size */
    char *bin_Buffer;
    struct List bin_UserFunctionList;
    struct List bin_UserGlobalVarList;
    struct List bin_DisplayDependenciesList;
};

struct funcBin
{
    void (*fb_Code)(short numArgs);
    short fb_NumArgs;
    bool fb_HasSideEffect;
};

struct sfwBin
{
    bool sb_IsSelectFromWhere;
    bool sb_Distinct;
    short sb_NumSelectItems;
    short sb_NumFromItems;
    short sb_NumOrderItems;
    bool sb_Where;
    struct SubProgram sb_WhereExpr;
    long sb_Continue;
};

struct VirtualFieldComputeCacheEntry
{
    struct Node vfcce_Node;
    struct Field *vfcce_Field;
    struct DisplayDependencies *vfcce_DisplayDependencies;
    struct Record *vfcce_Record;
    struct Element *vfcce_Element;
};

#endif

