//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtEditLabels.h
//
// Creation date: 02.03.2016
// Last modified: 10.04.2016
//
// EditLabels is a subclass of QFrame class.
// It consits of a QListWidget for a displaying a list
// of labels, an line-edit field for editing a label,
// and buttons for adding, removing and sorting of labels.
//

#ifndef QT_EDIT_LABELS_H
#define QT_EDIT_LABELS_H

#include "system.h"
#include "qt/qtUtil.h"
#include <QTreeWidget>

class EditLabels : public QWidget
{
    Q_OBJECT

public:
    EditLabels(QWidget *parent);

    char **labels();
    void setLabels(char **labels);

private slots:
    void currentItemChanged(QTreeWidgetItem *current);
    void newClick();
    void remClick();
    void sortClick();
    void onTextEdited(const QString &text);

private:
    QVector<char *>labels_;
    QVector<QByteArray> byteArrays_;
    QTreeWidget *tree_;
    QPushButton *new_;
    QPushButton *rem_;
    QPushButton *sort_;
    LineEditTreeView *edit_;

    QTreeWidgetItem *addText(const QString &text);
};

#endif

