//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtExtApplication.cc
//
// Creation date: 23.05.2010
// Last modified: 08.03.2022
//

#include "qtExtApplication.h"
#include "qt/qtGui.h"
#include <QAbstractEventDispatcher>
#include <QFileOpenEvent>
#include <QTimer>
#include <QThread>
#include "server.h"
#include "project.h"
#include "menu.h"
#include "menuproject.h"

ExtApplication::ExtApplication(int &argc, char **argv) : QApplication(argc, argv)
{
    setQuitOnLastWindowClosed(false);
    thread_ = QThread::currentThread();
    QAbstractEventDispatcher *dispatcher = QAbstractEventDispatcher::instance();
    connect(dispatcher, SIGNAL(aboutToBlock()), SLOT(update()));
    notifyDepth_ = 0;
    connect(this, SIGNAL(focusChanged(QWidget *, QWidget *)),
            this, SLOT(onFocusChanged(QWidget *, QWidget *)));
}

bool ExtApplication::notify(QObject *receiver, QEvent *event)
{
    if (QThread::currentThread() != thread_) {
        return QApplication::notify(receiver, event);
    }

    ++notifyDepth_;
    bool rc = QApplication::notify(receiver, event);
    --notifyDepth_;
    return rc;
}

void ExtApplication::interrupt()
{
    QAbstractEventDispatcher *dispatcher;
    dispatcher = QAbstractEventDispatcher::instance(QThread::currentThread());
    if (dispatcher) {
        dispatcher->interrupt();
    }
}

void ExtApplication::update()
{
    UpdateMenu(GuiActiveWindow(), false);
    UpdateProjects(false);
    if (notifyDepth_ <= 0) {
        ServerProcessRequests();
        UpdateProjects(true);
        while (!filesToOpen_.empty()) {
            QString filename = filesToOpen_.takeFirst();
            MenuProjectOpen(GuiActiveProject(), filename.toUtf8().data());
        }
    }
}

void ExtApplication::onFocusChanged(QWidget *old, QWidget *now)
{
    GuiStoreEdits();
}

bool ExtApplication::event(QEvent *event) 
{
    if (event->type() == QEvent::FileOpen) {
        QFileOpenEvent *openEvent = static_cast<QFileOpenEvent *>(event);
        filesToOpen_.append(openEvent->file());
        return true;
    }

    return QApplication::event(event);
}

