//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtGroupLayout.h
//
// Creation date: 17.06.2010
// Last modified: 27.04.2017
//

#ifndef QT_EXT_GRID_LAYOUT_H
#define QT_EXT_GRID_LAYOUT_H

#include <QGridLayout>

class GroupLayout : public QGridLayout
{
public:
    GroupLayout(int columns, QWidget *parent=0);

    // Clears contents margins on some systems.
    void maybeClearContentsMargins();

    void addLayout(QLayout *layout, int colSpan = 1);
    void addWidget(QWidget *widget, int colSpan = 1);
    
    void addLabelAndWidget(const QString &label, QWidget *widget,
                           QLayout *layout = 0);
    
    // Sets stretch factors of most recent layout/widget added.
    void setStretch(int horiz, int vert);

    int columns() const { return columns_; }

    bool hasMargin() const;

    Qt::Orientations expandingDirections() const;

private:
    int columns_;
    int row_;
    int col_;

    void nextPosition(int colSpan);
};

#endif

