//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtImageLabel.cc
//
// Allow to scale a QPixmap in a QFrame widget.
//
// Creation data: 29.04.2015
// Last modified: 28.05.2017
//

#include "qtImageLabel.h"
#include <QPainter>
#include <QPaintEvent>

ImageLabel::ImageLabel(QWidget *parent) : QFrame(parent)
{
    fixed_ = false;
    scaled_ = false;
    keepAspect_ = false;
    updateSize();
}

void ImageLabel::setFixed(bool fixed)
{
    fixed_ = fixed;
    updateSize();
}

void ImageLabel::setScaled(bool scaled)
{
    scaled_ = scaled;
    updateSize();
}

void ImageLabel::setKeepAspect(bool keepAspect)
{
    keepAspect_ = keepAspect;
    updateSize();
}

void ImageLabel::setPixmap(const QPixmap &pixmap)
{
    pixmap_ = pixmap;
    updateSize();
}

void ImageLabel::paintEvent(QPaintEvent *event) {
    QWidget::paintEvent(event);
    
    if (!pixmap_.isNull()) {
        QPainter painter(this);
        painter.setRenderHint(QPainter::Antialiasing);
    
        const QPixmap *pixmap = &pixmap_;
        QPixmap scaledPixmap;
        QSize widgetSize = size();
        if (scaled_) {
            Qt::AspectRatioMode mode = keepAspect_? 
                Qt::KeepAspectRatio : Qt::IgnoreAspectRatio;
            scaledPixmap = pixmap_.scaled(widgetSize, mode, 
                                          Qt::SmoothTransformation);
            pixmap = &scaledPixmap;
        }
        QSize diff2 = (widgetSize - pixmap->size()) / 2;
        painter.drawPixmap(QPoint(diff2.width(), diff2.height()), *pixmap);
    }
}

void ImageLabel::updateSize()
{
    if (fixed_) {
        setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        setFixedSize(pixmap_.size());
    } else {
        setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        setMinimumSize(50, 30);
        setMaximumSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
    }
    update();
}

