//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtImageLabel.h
//
// Allow to scale a QPixmap in a QFrame widget.
//
// Creation data: 29.04.2015
// Last modified: 28.05.2017
//

#ifndef QT_IMAGE_LABEL_H
#define QT_IMAGE_LABEL_H

#include <QFrame>
#include <QPixmap>

class ImageLabel : public QFrame
{
    Q_OBJECT
    
public:
    explicit ImageLabel(QWidget *parent = 0);
    const QPixmap &pixmap() const { return pixmap_; }
    
    void setFixed(bool fixed);
    bool fixed() const { return fixed_; }
    
    void setScaled(bool scaled);
    bool scaled() const { return scaled_; }
    
    void setKeepAspect(bool keepAspect);
    bool keepAspect() const { return keepAspect_; }
    
    virtual QSize sizeHint() const { return pixmap_.size(); }

public slots:
    void setPixmap(const QPixmap &pixmap);
    
protected:
    void paintEvent(QPaintEvent *event);
    
private:
    void updateSize();
    
    QPixmap pixmap_;
    bool fixed_;
    bool scaled_;
    bool keepAspect_;
};

#endif
