//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtPopEditLabels.c
//
// A button that when pressed pops up
// an EditLabels window for editing labels
//
// Creation data: 09.04.2016
// Last modified: 24.04.2016
//

#include "qtPopEditLabels.h"
#include "qtEditLabels.h"
#include "qt/qtUtil.h"
#include "labels.h"
#include "appstrings_cat.h"

class EditLabelsDialog : public CommonDialog
{
public:
    EditLabelsDialog(PopEditLabels *pop);

    char **labels() { return editLabels_->labels(); }
    void setLabels(char **labels) { editLabels_->setLabels(labels); }

private:
    PopEditLabels *pop_;
    EditLabels *editLabels_;

    virtual bool acceptEdits() { return pop_->acceptLabels(labels()); }
};

EditLabelsDialog::EditLabelsDialog(PopEditLabels *pop) :
    CommonDialog(pop), pop_(pop)
{
    editLabels_ = new EditLabels(this);
    contentsLayout()->addWidget(editLabels_);
    
    setOkText(GuiMarkShortcut(GCS(MSG_Ok)));
    setCancelText(GuiMarkShortcut(GCS(MSG_Cancel)));

    setWindowTitle(GCS(MSG_EditLabels));
}

PopEditLabels::PopEditLabels(QWidget *parent) : QPushButton(parent)
{
    dialog_ = new EditLabelsDialog(this);
    connect(this, SIGNAL(clicked()), this, SLOT(openPopup()));
    connect(dialog_, SIGNAL(accepted()), this, SLOT(updateLabels()));
    connect(dialog_, SIGNAL(finished(int)), this, SLOT(activate()));
}

char **PopEditLabels::labels()
{
    char **labels = 0;

    if (!labels_.empty()) {
        labels = labels_.data();
    }
    return labels;
}

void PopEditLabels::setLabels(char **labels)
{
    int count = NumLabels(labels);

    labels_.resize(count + 1);
    byteArrays_.resize(count);
    for (int i = 0; i < count; i++) {
        byteArrays_[i] = QByteArray(labels[i]);
        labels_[i] = byteArrays_[i].data();
    }
    labels_[count] = 0;
}

bool PopEditLabels::acceptLabels(char **labels) { return true; }

void PopEditLabels::openPopup()
{
    if (dialog_->isVisible()) {
        dialog_->activateWindow();
        dialog_->raise();
    } else {
        dialog_->setLabels(labels());
        dialog_->show();
    }
}

void PopEditLabels::updateLabels()
{
    setLabels(dialog_->labels());
    emit updated(labels());
}

void PopEditLabels::activate()
{
    activateWindow();
    window()->raise();
}

