/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** qtPopImage.h
**
** MUI's popimage class for Qt
**
** Creation data: 18.02.2016
** Last modified: 20.02.2016
*/

#ifndef QT_POP_IMAGE_H
#define QT_POP_IMAGE_H

#include "system.h"
#include <QDialog>
#include <QPointer>
#include <QToolButton>

class PopImageDialog;

class PopImage : public QToolButton
{
    Q_OBJECT
    
public:
    enum Type {
        Pattern = (1 << 0),
        Color = (1 << 1),
        External = (1 << 2),
        All = 0xff,
    };

    PopImage(QWidget *parent, Project *pr);

    const QString &spec() const { return spec_; }

    void setTypes(int types) { types_ = types; }
    int types() const { return types_; }

    virtual QSize sizeHint() const
    {
        QSize size = QToolButton::sizeHint();
        size.setWidth(std::max(size.width(), 48));
        size.setHeight(std::max(size.height(), 48));
        return size;
    }
    
signals:
    void changed(bool isDefault);

public slots:
    void openPopup();    
    void setSpec(const QString &spec);
    void clear(bool clear) { if (clear) setSpec(QString()); }
    
private:
    Project *pr_;
    QString spec_;
    int types_;
    QPointer<PopImageDialog> dialog_;
    
    void placeDialog();

private slots:
    void activate();
};

void qtSetWidgetBackground(QWidget *widget, const QString &spec);

#endif  // QT_POP_IMAGE_H

