/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** qtPopSelection.h
**
** an implementation of MUI's popasl class for Qt
**
** Creation date: 13.03.2015
** Last modified: 16.10.2017
*/

#ifndef QT_POP_SELECTION_H
#define QT_POP_SELECTION_H

/*
** As a subclass of PopString class, PopSelection can be used to pop up
** a selection box for choosing a file, or a font.
**
** Using this class, you don't need to worry about handling the 
** selection box.  It will automatically be opened when the popup
** button is pressed and update the corresponding string object
** when the user terminates the selection box. From the programmers
** point of view, all you have to do is to handle the string
** object contents.
*/

#include "qtPopString.h"
#include "qt/qtAmiFileDialog.h"
#include <QFontDialog>

class PopSelection : public PopString
{
    Q_OBJECT
    
public:
    enum Type {
        FileSelection,
        FontSelection
    };
    
    PopSelection();
    
    void setType(Type type) { type_ = type; }
    Type type() const { return type_; }
    
    void setSaveMode(bool saveMode) { saveMode_ = saveMode; }
    bool saveMode() const { return saveMode_; }

    void setDefaultSuffix(const QString &suffix) { defaultSuffix_ = suffix; }
    const QString &defaultSuffix() const { return defaultSuffix_; }
    
    AmiFileDialog *fileDialog() const;
    QFontDialog *fontDialog() const;

public slots:
    void dialogFinished(int result);
    
protected:
    virtual bool start();
    virtual void stop();
    
    virtual void open(void);
    virtual void close(bool success);

private:
    Type type_;
    bool saveMode_;
    QString defaultSuffix_;
};

#endif
