//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtPopWidget.c
//
// an implementation of MUI's popobject class for Qt
//
// Creation date: 29.08.2010
// Last modified: 09.10.2010
//

#include "qtPopWidget.h"
#include "qtGroupLayout.h"
#include <QCloseEvent>

#define USE_POPUP
#undef USE_MODAL

class PopupWindow : public QWidget
{
public:
    PopupWindow(PopWidget *pop);
    
    void closeEvent(QCloseEvent *event);
    
private:
    PopWidget *pop_;
};

PopupWindow::PopupWindow(PopWidget *pop)
{
    pop_ = pop;
    if (pop->light()) {
#ifdef USE_POPUP
        setWindowFlags(Qt::Popup | Qt::FramelessWindowHint);
#else
        setWindowFlags(Qt::Window | Qt::FramelessWindowHint);
#endif
    } else {
        setWindowFlags(Qt::Dialog);
    }
}
 
void PopupWindow::closeEvent(QCloseEvent *event)
{
    event->ignore();
    pop_->closePopup(false);
}
    

PopWidget::PopWidget()
{
    widget_ = 0;
    parent_ = 0;
    light_ = true;
}

void PopWidget::setPopupWidget(QWidget *widget)
{
    widget_ = widget;
    if (widget) {
        widget->hide();
    }
}

void PopWidget::open()
{
    QWidget *popup = this->popup();
    
    if (!popup) {
        if (!widget_) {
            return;
        }
        
        popup = new PopupWindow(this);
#ifdef USE_MODAL
        if (light()) {
            popup->setWindowModality(Qt::ApplicationModal);
        }
#endif

        GroupLayout *group = new GroupLayout(1, popup);
        if (light()) {
            group->setContentsMargins(0, 0, 0, 0);
        }
        parent_ = widget_->parentWidget();
        widget_->setParent(popup);
        widget_->show();
        group->addWidget(widget_);
        setPopup(popup);
        widget_->setFocus();
    }

    if (!start()) {
        close(false);
        return;
    }
    popup->show();
    popup->raise();
    popup->activateWindow();
}

void PopWidget::close(bool success)
{
    if (success) {
        stop();
    }

    QWidget *popup = this->popup();
    if (popup) {
        popup->hide();
    }
    if (widget_) {
        widget_->hide();
        widget_->setParent(parent_);
    }

    setPopup(0);
}
