//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtPopWidget.h
//
// an implementation of MUI's popobject class for Qt
//
// Creation date: 29.08.2010
// Last modified: 09.10.2010
//

#ifndef QT_POP_WIDGET_H
#define QT_POP_WIDGET_H

//
// PopWidget class takes any QWidget as parameter and uses it
// as popup. You can e.g. simply create a QListWidget with
// some entries and the PopWidget class will create a window
// around it and display it when the user hits the popup button.
//

#include "qtPopString.h"

class PopWidget : public PopString
{
    Q_OBJECT
    
public:
    PopWidget();

    void setPopupWidget(QWidget *widget);
    QWidget *popupWidget() { return widget_; }
    
    void setLight(bool light) { light_ = light; }
    bool light() const { return light_; }
    
protected:
    virtual bool start() { return true; }
    virtual void stop() {}
    
    virtual void open(void);
    virtual void close(bool success);
    
private:
    QPointer<QWidget> widget_;
    QWidget *parent_;
    bool light_;
};
    
#endif
