//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtQuickSearch.h
//
// A popup window with a QLineEdit for entering a search string.
// The popup window is placed relative to a parent window at the 
// bottom right corner.
//
// Creation data: 19.04.2015
// Last modified: 19.04.2015
//

#ifndef QT_QUICK_SEARCH_H
#define QT_QUICK_SEARCH_H

#include <system.h>
#include <QLineEdit>
#include <QKeyEvent>

class QuickSearch : public QWidget
{
    Q_OBJECT
    
public:
    enum Action {
        START, PREV, NEXT, COMMIT, CANCEL
    };
    
    QuickSearch(QWidget *parent);
    
    void processEvent(QEvent *event);

    static bool isStartEvent(const QKeyEvent *event)
    {
        return !event->text().isEmpty() && event->key() != Qt::Key_Escape;
    }
    
signals:
    void search(const QString &text, QuickSearch::Action action);
    
private:
    QLineEdit *lineEdit_;
};

#endif

