//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtQueryEditor.cc
//
// Creation date: 14.12.2015
// Last modified: 21.10.2018
//

#ifndef QT_SORTABLE_LIST_MODEL_H
#define QT_SORTABLE_LIST_MODEL_H

#include "qt/classes/qtSortableAbstractListModel.h"
#include "system.h"
#include "util.h"

struct List;
struct Node;

class SortableListModel : public SortableAbstractListModel
{
public:
    SortableListModel(QObject *parent) : SortableAbstractListModel(parent) 
    {
        list_ = 0;
    }

    void setList(List *list)
    {
        beginResetModel();
        list_ = list;
        endResetModel();
    }

    QModelIndex nodeIndex(Node *node) const
    {
        if (node && list_) {
            int ix = 0;
            Node *n;
            FORNODE(n, list_) {
                if (filter(n)) {
                    if (n == node) {
                        return SortableAbstractListModel::index(ix, 0);
                    }
                    ix++;
                }
            }
        }
        return QModelIndex();
    }
    
    Node *node(const QModelIndex &index) const
    {
        if (index.isValid()) {
            return node(index.row());
        }
        return 0;
    }
    
    Node *node(int ix) const {
        if (list_ && ix >= 0) {
            Node *n;
            FORNODE(n, list_) {
                if (filter(n)) {
                    if (ix == 0) {
                        return n;
                    }
                    ix--;
                }
            }
        }
        return 0;
    }
    
protected:
    int numElements() const
    {
        int num = 0;
        if (list_) {
            Node *n;
            FORNODE(n, list_) {
                if (filter(n)) {
                    num++;
                }
            }
        }
        return num;
    }
    
    bool moveElement(int from, int to)
    {
        Node *n = node(from);
        Node *pred = node(to);
        if (!n || n == pred || !list_) {
            return false;
        }
        
        REMOVE(n);        
        if (pred) {
            pred = PRED(pred);
        } else {
            pred = TAILPRED(list_);
        }
        INSERT(list_, n, pred);
        return true;
    }
    
    virtual bool filter(Node *n) const { return true; }
    
private:
    List *list_;
};

#endif
