//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtGui.h
//
// Creation date: 03.03.2009
// Last modified: 03.02.2022
//

#ifndef QT_GUI_H
#define QT_GUI_H

#include "system.h"

typedef const char *CatalogString;
#define GCS(ref) GuiGetTranslation(ref)

#ifdef __cplusplus
class QWidget;
typedef QWidget *GuiObject;
#else
struct QWidget;
typedef struct QWidget *GuiObject;
#endif
  
struct Project;
struct Field;
struct Record;
struct DisplayObject;
struct Element;
struct WindowDimensions;

#ifdef __cplusplus
extern "C" {
#endif

extern char DefaultRealFormat, DefaultDateFormat;

void CloseGui(void);
const char *OpenGui(int *pargc, char **argv);    
/* returns error string or NULL on success */

char *GuiGetTranslation(const char *s);

void GuiPrefsUpdated(void);

void GuiBeep(void);

const char *GuiLanguage();

void GuiAbout(void);

void GuiSendQuitMessage(void);

ulong GuiSleep(void);
void GuiSetSleep(bool sleep);
void GuiClearWindowSleep(GuiObject w);
ulong GuiProjectSleep(struct Project *pr);
void GuiSetProjectSleep(struct Project *pr, bool sleep);

char *GuiEditorText(GuiObject go, struct MemPool *memPool);
void GuiSetEditorText(GuiObject go, const char *str);
void GuiSetEditorChanged(GuiObject edit, bool changed);

void GuiSetRegisterPage(GuiObject go, long pos);
long GuiRegisterActivePage(GuiObject go);

struct Project *GuiWindowProject(GuiObject go);
struct Project *GuiObjectProject(GuiObject go);
    
bool GuiOpenWindow(GuiObject wi);
void GuiCloseWindow(GuiObject wi);

short GuiObjectWeight(GuiObject go, bool horiz);
const char *GuiObjectHelpNode(GuiObject go);
GuiObject GuiObjectParent(GuiObject go);
    
void GuiSetWindowDimensions(GuiObject win, const struct WindowDimensions *wd);
bool GuiGetWindowDimensions(GuiObject win, struct WindowDimensions *wd);
struct Project *GuiActiveProject(void);
GuiObject GuiActiveWindow(void);
GuiObject GuiActiveObject(GuiObject wi);
bool GuiIsEditorObject(GuiObject go);

struct DisplayObject *GuiObjectDisplayObject(GuiObject go);
void SetGuiObjectDisplayObject(GuiObject go, struct DisplayObject *dio);

void GuiSetSelected(GuiObject go, bool selected);
bool GuiGetEnabled(GuiObject go);
void GuiSetEnabled(GuiObject go, bool enabled);
void GuiSetBackground(GuiObject go, const char *bg);
long GuiSFWListActive(GuiObject go);
void GuiSFWListSetActive(GuiObject go, long num);
long GuiListActive(GuiObject go);
void *GuiListActiveEntry(GuiObject go);
void GuiListSetActive(GuiObject go, long num);
long GuiListFindNode(GuiObject go, void *node);
void *GuiListNthEntry(GuiObject go, long num);
long GuiListNumEntries(GuiObject go);
char GuiSFWListNumColumns(GuiObject go);
const struct QueryFieldInfo *GuiSFWListFieldInfos(GuiObject go);
const signed char *GuiSFWListColumnOrder(GuiObject go);
const struct QueryLine *GuiSFWListQueryLine(GuiObject go, long row);
struct Table *GuiSFWListControlTable(GuiObject go);
struct Record *GuiSFWListActiveRecord(GuiObject go);
void GuiSFWListSetActiveRecord(GuiObject go, struct Record *rec);
struct Record *GuiSFWListRecord(GuiObject go, long row);
    
const char *GuiStringContents(GuiObject go);    // only for text input fields
const char *GuiObjectText(GuiObject go);        // also non-input, encoding

bool GuiWindowOpen(GuiObject wi);
void GuiActivateWindow(GuiObject wi);
void GuiWindowToFront(GuiObject wi);
void GuiSetActiveGuiObject(GuiObject wi, GuiObject go);
void GuiSetWindowTitle(GuiObject wi, const char *title);
void GuiSetPrependWindowTitle(GuiObject wi, const char *prepend);

void GuiStoreEdits(void);

void GuiMainLoop(bool (*reallyQuit)(void));
bool GuiMainLoopIteration(void);

void GuiShowHelp(const char *section);

void GuiUpdateExtraButtonsInTabChain(void);

#ifdef __cplusplus
}
#endif

#endif

