//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtSetFormats.cc
//
// Creation date: 28.09.2015
// Last modified: 28.09.2015
//

#include "system.h"
#include "qt/qtUtil.h"
#include "qt/classes/qtGroupLayout.h"
#include "setformats.h"
#include "main.h"
#include "gui.h"
#include "project.h"
#include "preferences.h"
#include "memory.h"
#include "appstrings_cat.h"

class SetFormatsDialog : public CommonDialog
{
    Q_OBJECT

public:
    explicit SetFormatsDialog(Project *pr);

private:
    Project *pr_;
    RadioBox *realFormat_;
    RadioBox *dateFormat_;

    virtual bool acceptEdits() {
        SetPrefsValue(pr_, PREFS_REALFORMAT, realFormat_->checkedId());
        SetPrefsValue(pr_, PREFS_DATEFORMAT, dateFormat_->checkedId());

        Project *pr;
        FORNODE(pr, &ProjectList) {
            GuiUpdate(pr);
	}
        return true;
    }
};

SetFormatsDialog::SetFormatsDialog(Project *pr) : 
    CommonDialog(GuiFindParentWindow(0, pr)), pr_(pr)
{
    setWindowTitle(GCS(MSG_Formats));
    setOkText(GuiMarkShortcut(GCS(MSG_Ok)));
    setCancelText(GuiMarkShortcut(GCS(MSG_Cancel)));

    GroupLayout *group = new GroupLayout(1);
    contentsLayout()->addLayout(group);

    static char *realformats[3];
    realformats[0] = GCS(MSG_Formats_RealFormat_DecimalPoint);
    realformats[1] = GCS(MSG_Formats_RealFormat_DecimalComma);
    realformats[2] = NULL;

    realFormat_ = new RadioBox(this, realformats,
            GCS(MSG_Formats_RealFormat), true, false);
    realFormat_->setCheckedId(GetPrefsValue(pr, PREFS_REALFORMAT));
    group->addWidget(realFormat_);

    static char *dateformats[4];
    dateformats[0] = GCS(MSG_Formats_DateFormat_DayMonthYear);
    dateformats[1] = GCS(MSG_Formats_DateFormat_MonthDayYear);
    dateformats[2] = GCS(MSG_Formats_DateFormat_YearMonthDay);
    dateformats[3] = NULL;

    dateFormat_ = new RadioBox(this, dateformats,
            GCS(MSG_Formats_DateFormat), true, false);
    dateFormat_->setCheckedId(GetPrefsValue(pr, PREFS_DATEFORMAT));
    group->addWidget(dateFormat_);

    GuiSetWindowProject(this, pr);
    GuiSetHelpNode(this, "Formats");
}

void GuiSetFormats(Project *pr)
{
    GuiBusyCursor busy;
    SetFormatsDialog dialog(pr);
    dialog.exec();
}

#include "qtSetFormats.moc"
