//
// BeeBase -- a relational programmable database with GUI
// Copyright (C) 1998-2022 Steffen Gutmann
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <https://www.gnu.org/licenses/>. 
//
// qtStructureEditor.h
//
// Creation date: 18.02.2016
// Last modified: 26.02.2017
//

#ifndef QT_STRUCTURE_EDITOR_UTIL_H
#define QT_STRUCTURE_EDITOR_UTIL_H

#include "system.h"
#include "qt/classes/qtPopImage.h"
#include "qt/classes/qtPopSelection.h"
#include "qt/classes/qtPopString.h"
#include "qt/classes/qtSortableListModel.h"
#include <QCheckBox>
#include <QHBoxLayout>
#include <QLineEdit>
#include <QSlider>
#include "structureeditor.h"
#include "table.h"
#include "util.h"

void CheckShortCut(QLineEdit *edit, DisplayObject *dio);
PopString *UserFunctionsPopup(QLineEdit *string, Project *pr, QWidget *parent);
QHBoxLayout *WeightSlider(QSlider *slider, QWidget *parent);
QHBoxLayout *BackgroundGadgets(PopImage *popImage, QCheckBox *checkBox, 
                               const QString &bg);

class TablesModel : public SortableListModel
{
public:
    TablesModel(QObject *parent) : SortableListModel(parent) {}
    
    QModelIndex tableIndex(Table *tab) const { return nodeIndex((Node *)tab); }
    Table *table(const QModelIndex &index) const 
    { return (Table *)node(index); }
    Table *table(int ix) const { return (Table *)node(ix); }
    
    virtual bool filter(Node *n) const { return TableSystemFilter(n); }
    
protected:
    QString display(int ix) const { return TableName(table(ix)); }
};

class FieldsModel : public SortableListModel
{
public:
    FieldsModel(QObject *parent) : SortableListModel(parent) {}
    
    QModelIndex fieldIndex(Field *field) const 
    { return nodeIndex((Node *)field); }
    Field *field(const QModelIndex &index) const 
    { return (Field *)node(index); }
    Field *field(int ix) const { return (Field *)node(ix); }
    
protected:
    QString display(int ix) const { return FieldName(field(ix)); }
};

#endif

