/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** exec.c
**
** Recover from software failure or stack overflow
**
** Creation date: 04.01.2005
** Last modified: 04.01.2005
*/

#include "exec.h"
#include "main.h"
#include "menuproject.h"
#include "project.h"
#include "requesters.h"
#include "appstrings_cat.h"
#include <signal.h>

void sigHandler(int signum)
{
    bool is_stackoverflow = FALSE;
    struct Project *pr;

    DFPRINTF((stderr, "caught signal %d\n", signum));

    GuiSetSleep(TRUE);             /* disable all user input */

    FORNODE(pr, &ProjectList) {
        const char *name = ProjectName(pr);
	int result;

        if (!name) {
            name = GCS(MSG_Unnamed);
	}

        if (is_stackoverflow) {
	    result = Ask(AT_ERROR, GCS(MSG_SoftwareFailureAnswers),
		    GCS(MSG_StackOverflow), name);
	} else {
            result = Ask(AT_ERROR, GCS(MSG_SoftwareFailureAnswers),
                GCS(MSG_SoftwareFailure), signum, name);
	}

        if (result) {
      	    MenuProjectSaveAs(pr);
	}
    }

    fail(NULL, 20);
}

static struct
{
    int signum;
    void (*handler)(int);
} sigdata[] = { 
    { SIGHUP, SIG_IGN },
    { SIGILL, sigHandler },
    { SIGFPE, sigHandler },
    { SIGSEGV, sigHandler },
    { SIGPIPE, sigHandler },
    { SIGBUS, sigHandler },
#ifdef SIGPOLL
    { SIGPOLL, sigHandler },
#endif
};
    
#define NUM_SIG_DATA (sizeof(sigdata) / sizeof(sigdata[0]))
    
void InstallSignalHandlers()
{
    size_t i;

    for (i=0; i < NUM_SIG_DATA; i++) {
	signal(sigdata[i].signum, sigdata[i].handler);
    }
}

void RestoreSignalHandlers()
{
    size_t i;

    for (i=0; i < NUM_SIG_DATA; i++) {
	signal(sigdata[i].signum, SIG_DFL);
    }
}

