/*
** BeeBase -- a relational programmable database with GUI
** Copyright (C) 1998-2022 Steffen Gutmann
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 3
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, see <https://www.gnu.org/licenses/>. 
**
** foo.h
**
** Creation date: 22.12.2001
** Last modified: 30.01.2009
*/

#ifndef FOO_H
#define FOO_H

#include "system.h"

typedef const char *CatalogString;
#define GCS(ref) (char *)(ref)

typedef void *GuiObject;
  
struct Project;
struct Field;
struct Element;
struct WindowDimensions;

#ifdef __cplusplus
extern "C" {
#endif

extern char DefaultRealFormat, DefaultDateFormat;

void CloseGui(void);
const char *OpenGui(int *pargc, char **argv);    
/* returns error string or NULL on success */

void GuiPrefsUpdated(void);

void GuiBeep(void);

#define GuiLanguage() "english"

void GuiAbout(void);

void GuiSendQuitMessage(void);

ulong GuiSleep(void);
void GuiSetSleep(bool sleep);
void GuiClearWindowSleep(GuiObject w);
void GuiSetProjectSleep(struct Project *pr, bool sleep);

char *GuiEditorText(GuiObject go, struct MemPool *memPool);
void GuiSetEditorText(GuiObject go, const char *str);
void GuiSetEditorChanged(GuiObject edit, bool changed);

void GuiSetRegisterPage(GuiObject go, long pos);
long GuiRegisterActivePage(GuiObject go);

struct Project *GuiWindowProject(GuiObject go);

bool GuiOpenWindow(GuiObject wi);
void GuiCloseWindow(GuiObject wi);

short GuiObjectWeight(GuiObject obj, bool horiz);

void GuiSetWindowDimensions(GuiObject win, const struct WindowDimensions *wd);
bool GuiGetWindowDimensions(GuiObject win, struct WindowDimensions *wd);
GuiObject GuiActiveWindow(void);
GuiObject GuiActiveObject(GuiObject wi);
bool GuiIsEditorObject(GuiObject go);

struct DisplayObject *GuiObjectDisplayObject(GuiObject go);

void GuiSetSelected(GuiObject go, bool selected);
void GuiSetDisabled(GuiObject go, bool disabled);
long GuiListActive(GuiObject go);
void *GuiListActiveEntry(GuiObject go);
void GuiListSetActive(GuiObject go, long num);
long GuiListFindNode(GuiObject go, void *node);
void *GuiListNthEntry(GuiObject go, long num);

const char *GuiStringContents(GuiObject go);    // only for text input fields
const char *GuiObjectText(GuiObject go);        // also non-input, encoding

bool GuiWindowOpen(GuiObject wi);
void GuiActivateWindow(GuiObject wi);
void GuiWindowToFront(GuiObject wi);
void GuiSetActiveGuiObject(GuiObject wi, GuiObject go);
void GuiSetWindowTitle(GuiObject wi, const char *title);

void GuiStoreEdits(void);

void GuiMainLoop(bool (*reallyQuit)(void));
bool GuiMainLoopIteration(void);

void GuiShowHelp(const char *section);

#ifdef __cplusplus
}
#endif

#endif

